# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: enterprise.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x65nterprise.proto\x12\nEnterprise\"\x84\x01\n\x18\x45nterpriseKeyPairRequest\x12\x1b\n\x13\x65nterprisePublicKey\x18\x01 \x01(\x0c\x12%\n\x1d\x65ncryptedEnterprisePrivateKey\x18\x02 \x01(\x0c\x12$\n\x07keyType\x18\x03 \x01(\x0e\x32\x13.Enterprise.KeyType\"\'\n\x14GetTeamMemberRequest\x12\x0f\n\x07teamUid\x18\x01 \x01(\x0c\"k\n\x0e\x45nterpriseUser\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x01(\x03\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x1a\n\x12\x65nterpriseUsername\x18\x03 \x01(\t\x12\x14\n\x0cisShareAdmin\x18\x04 \x01(\x08\"K\n\x15GetTeamMemberResponse\x12\x32\n\x0e\x65nterpriseUser\x18\x01 \x03(\x0b\x32\x1a.Enterprise.EnterpriseUser\"-\n\x11\x45nterpriseUserIds\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x03(\x03\"B\n\x19\x45nterprisePersonalAccount\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x16\n\x0eOBSOLETE_FIELD\x18\x02 \x01(\x0c\"S\n\x17\x45ncryptedTeamKeyRequest\x12\x0f\n\x07teamUid\x18\x01 \x01(\x0c\x12\x18\n\x10\x65ncryptedTeamKey\x18\x02 \x01(\x0c\x12\r\n\x05\x66orce\x18\x03 \x01(\x08\"+\n\x0fReEncryptedData\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\t\"?\n\x12ReEncryptedRoleKey\x12\x0f\n\x07role_id\x18\x01 \x01(\x03\x12\x18\n\x10\x65ncryptedRoleKey\x18\x02 \x01(\x0c\"\x9d\x02\n\x1bNodeToManagedCompanyRequest\x12\x11\n\tcompanyId\x18\x01 \x01(\x05\x12*\n\x05nodes\x18\x02 \x03(\x0b\x32\x1b.Enterprise.ReEncryptedData\x12*\n\x05roles\x18\x03 \x03(\x0b\x32\x1b.Enterprise.ReEncryptedData\x12*\n\x05users\x18\x04 \x03(\x0b\x32\x1b.Enterprise.ReEncryptedData\x12\x30\n\x08roleKeys\x18\x05 \x03(\x0b\x32\x1e.Enterprise.ReEncryptedRoleKey\x12\x35\n\x08teamKeys\x18\x06 \x03(\x0b\x32#.Enterprise.EncryptedTeamKeyRequest\",\n\x08RoleTeam\x12\x0f\n\x07role_id\x18\x01 \x01(\x03\x12\x0f\n\x07teamUid\x18\x02 \x01(\x0c\"4\n\tRoleTeams\x12\'\n\trole_team\x18\x01 \x03(\x0b\x32\x14.Enterprise.RoleTeam\"\xc1\x03\n\x16\x45nterpriseRegistration\x12\x18\n\x10\x65ncryptedTreeKey\x18\x01 \x01(\x0c\x12\x16\n\x0e\x65nterpriseName\x18\x02 \x01(\t\x12\x14\n\x0crootNodeData\x18\x03 \x01(\x0c\x12\x15\n\radminUserData\x18\x04 \x01(\x0c\x12\x11\n\tadminName\x18\x05 \x01(\t\x12\x10\n\x08roleData\x18\x06 \x01(\x0c\x12\x38\n\nrsaKeyPair\x18\x07 \x01(\x0b\x32$.Enterprise.EnterpriseKeyPairRequest\x12\x13\n\x0bnumberSeats\x18\x08 \x01(\x05\x12\x32\n\x0e\x65nterpriseType\x18\t \x01(\x0e\x32\x1a.Enterprise.EnterpriseType\x12\x15\n\rrolePublicKey\x18\n \x01(\x0c\x12*\n\"rolePrivateKeyEncryptedWithRoleKey\x18\x0b \x01(\x0c\x12#\n\x1broleKeyEncryptedWithTreeKey\x18\x0c \x01(\x0c\x12\x38\n\neccKeyPair\x18\r \x01(\x0b\x32$.Enterprise.EnterpriseKeyPairRequest\".\n\x1a\x44omainPasswordRulesRequest\x12\x10\n\x08username\x18\x01 \x01(\t\"\\\n\x19\x44omainPasswordRulesFields\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x07minimum\x18\x02 \x01(\x05\x12\x0f\n\x07maximum\x18\x03 \x01(\x05\x12\x0f\n\x07\x61llowed\x18\x04 \x01(\x08\"E\n\x10LoginToMcRequest\x12\x16\n\x0emcEnterpriseId\x18\x01 \x01(\x05\x12\x19\n\x11messageSessionUid\x18\x02 \x01(\x0c\"L\n\x11LoginToMcResponse\x12\x1d\n\x15\x65ncryptedSessionToken\x18\x01 \x01(\x0c\x12\x18\n\x10\x65ncryptedTreeKey\x18\x02 \x01(\t\"g\n\x1b\x44omainPasswordRulesResponse\x12H\n\x19\x64omainPasswordRulesFields\x18\x01 \x03(\x0b\x32%.Enterprise.DomainPasswordRulesFields\"\x88\x01\n\x18\x41pproveUserDeviceRequest\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x01(\x03\x12\x1c\n\x14\x65ncryptedDeviceToken\x18\x02 \x01(\x0c\x12\x1e\n\x16\x65ncryptedDeviceDataKey\x18\x03 \x01(\x0c\x12\x14\n\x0c\x64\x65nyApproval\x18\x04 \x01(\x08\"t\n\x19\x41pproveUserDeviceResponse\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x01(\x03\x12\x1c\n\x14\x65ncryptedDeviceToken\x18\x02 \x01(\x0c\x12\x0e\n\x06\x66\x61iled\x18\x03 \x01(\x08\x12\x0f\n\x07message\x18\x04 \x01(\t\"Y\n\x19\x41pproveUserDevicesRequest\x12<\n\x0e\x64\x65viceRequests\x18\x01 \x03(\x0b\x32$.Enterprise.ApproveUserDeviceRequest\"\\\n\x1a\x41pproveUserDevicesResponse\x12>\n\x0f\x64\x65viceResponses\x18\x01 \x03(\x0b\x32%.Enterprise.ApproveUserDeviceResponse\"b\n\x15\x45nterpriseUserDataKey\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x01(\x03\x12\x1c\n\x14userEncryptedDataKey\x18\x02 \x01(\x0c\x12\x11\n\tkeyTypeId\x18\x03 \x01(\x05\"I\n\x16\x45nterpriseUserDataKeys\x12/\n\x04keys\x18\x01 \x03(\x0b\x32!.Enterprise.EnterpriseUserDataKey\"2\n\x15\x45nterpriseDataRequest\x12\x19\n\x11\x63ontinuationToken\x18\x01 \x01(\x0c\"0\n\x13SpecialProvisioning\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xcc\x01\n\x11GeneralDataEntity\x12\x16\n\x0e\x65nterpriseName\x18\x01 \x01(\t\x12\x1a\n\x12restrictVisibility\x18\x02 \x01(\x08\x12<\n\x13specialProvisioning\x18\x04 \x01(\x0b\x32\x1f.Enterprise.SpecialProvisioning\x12\x30\n\ruserPrivilege\x18\x07 \x01(\x0b\x32\x19.Enterprise.UserPrivilege\x12\x13\n\x0b\x64istributor\x18\x08 \x01(\x08\"\xfd\x01\n\x04Node\x12\x0e\n\x06nodeId\x18\x01 \x01(\x03\x12\x10\n\x08parentId\x18\x02 \x01(\x03\x12\x10\n\x08\x62ridgeId\x18\x03 \x01(\x03\x12\x0e\n\x06scimId\x18\x04 \x01(\x03\x12\x11\n\tlicenseId\x18\x05 \x01(\x03\x12\x15\n\rencryptedData\x18\x06 \x01(\t\x12\x12\n\nduoEnabled\x18\x07 \x01(\x08\x12\x12\n\nrsaEnabled\x18\x08 \x01(\x08\x12 \n\x14ssoServiceProviderId\x18\t \x01(\x03\x42\x02\x18\x01\x12\x1a\n\x12restrictVisibility\x18\n \x01(\x08\x12!\n\x15ssoServiceProviderIds\x18\x0b \x03(\x03\x42\x02\x10\x01\"\x8e\x01\n\x04Role\x12\x0e\n\x06roleId\x18\x01 \x01(\x03\x12\x0e\n\x06nodeId\x18\x02 \x01(\x03\x12\x15\n\rencryptedData\x18\x03 \x01(\t\x12\x0f\n\x07keyType\x18\x04 \x01(\t\x12\x14\n\x0cvisibleBelow\x18\x05 \x01(\x08\x12\x16\n\x0enewUserInherit\x18\x06 \x01(\x08\x12\x10\n\x08roleType\x18\x07 \x01(\t\"\xdc\x01\n\x04User\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x01(\x03\x12\x0e\n\x06nodeId\x18\x02 \x01(\x03\x12\x15\n\rencryptedData\x18\x03 \x01(\t\x12\x0f\n\x07keyType\x18\x04 \x01(\t\x12\x10\n\x08username\x18\x05 \x01(\t\x12\x0e\n\x06status\x18\x06 \x01(\t\x12\x0c\n\x04lock\x18\x07 \x01(\x05\x12\x0e\n\x06userId\x18\x08 \x01(\x05\x12\x1e\n\x16\x61\x63\x63ountShareExpiration\x18\t \x01(\x03\x12\x10\n\x08\x66ullName\x18\n \x01(\t\x12\x10\n\x08jobTitle\x18\x0b \x01(\t\"7\n\tUserAlias\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x01(\x03\x12\x10\n\x08username\x18\x02 \x01(\t\"\xac\x01\n\x18\x43omplianceReportMetaData\x12\x11\n\treportUid\x18\x01 \x01(\x0c\x12\x0e\n\x06nodeId\x18\x02 \x01(\x03\x12\x12\n\nreportName\x18\x03 \x01(\t\x12\x15\n\rdateGenerated\x18\x04 \x01(\x03\x12\x11\n\trunByName\x18\x05 \x01(\t\x12\x16\n\x0enumberOfOwners\x18\x07 \x01(\x05\x12\x17\n\x0fnumberOfRecords\x18\x08 \x01(\x05\"S\n\x0bManagedNode\x12\x0e\n\x06roleId\x18\x01 \x01(\x03\x12\x15\n\rmanagedNodeId\x18\x02 \x01(\x03\x12\x1d\n\x15\x63\x61scadeNodeManagement\x18\x03 \x01(\x08\"T\n\x0fUserManagedNode\x12\x0e\n\x06nodeId\x18\x01 \x01(\x03\x12\x1d\n\x15\x63\x61scadeNodeManagement\x18\x02 \x01(\x08\x12\x12\n\nprivileges\x18\x03 \x03(\t\"w\n\rUserPrivilege\x12\x35\n\x10userManagedNodes\x18\x01 \x03(\x0b\x32\x1b.Enterprise.UserManagedNode\x12\x18\n\x10\x65nterpriseUserId\x18\x02 \x01(\x03\x12\x15\n\rencryptedData\x18\x03 \x01(\t\"4\n\x08RoleUser\x12\x0e\n\x06roleId\x18\x01 \x01(\x03\x12\x18\n\x10\x65nterpriseUserId\x18\x02 \x01(\x03\"M\n\rRolePrivilege\x12\x15\n\rmanagedNodeId\x18\x01 \x01(\x03\x12\x0e\n\x06roleId\x18\x02 \x01(\x03\x12\x15\n\rprivilegeType\x18\x03 \x01(\t\"I\n\x0fRoleEnforcement\x12\x0e\n\x06roleId\x18\x01 \x01(\x03\x12\x17\n\x0f\x65nforcementType\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xa9\x01\n\x04Team\x12\x0f\n\x07teamUid\x18\x01 \x01(\x0c\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06nodeId\x18\x03 \x01(\x03\x12\x14\n\x0crestrictEdit\x18\x04 \x01(\x08\x12\x15\n\rrestrictShare\x18\x05 \x01(\x08\x12\x14\n\x0crestrictView\x18\x06 \x01(\x08\x12\x15\n\rencryptedData\x18\x07 \x01(\t\x12\x18\n\x10\x65ncryptedTeamKey\x18\x08 \x01(\t\"G\n\x08TeamUser\x12\x0f\n\x07teamUid\x18\x01 \x01(\x0c\x12\x18\n\x10\x65nterpriseUserId\x18\x02 \x01(\x03\x12\x10\n\x08userType\x18\x03 \x01(\t\"K\n\x1aGetDistributorInfoResponse\x12-\n\x0c\x64istributors\x18\x01 \x03(\x0b\x32\x17.Enterprise.Distributor\"B\n\x0b\x44istributor\x12\x0c\n\x04name\x18\x01 \x01(\t\x12%\n\x08mspInfos\x18\x02 \x03(\x0b\x32\x13.Enterprise.MspInfo\"\xf3\x01\n\x07MspInfo\x12\x14\n\x0c\x65nterpriseId\x18\x01 \x01(\x05\x12\x16\n\x0e\x65nterpriseName\x18\x02 \x01(\t\x12\x19\n\x11\x61llocatedLicenses\x18\x03 \x01(\x05\x12\x19\n\x11\x61llowedMcProducts\x18\x04 \x03(\t\x12\x15\n\rallowedAddOns\x18\x05 \x03(\t\x12\x17\n\x0fmaxFilePlanType\x18\x06 \x01(\t\x12\x34\n\x10managedCompanies\x18\x07 \x03(\x0b\x32\x1a.Enterprise.ManagedCompany\x12\x1e\n\x16\x61llowUnlimitedLicenses\x18\x08 \x01(\x08\"\x91\x02\n\x0eManagedCompany\x12\x16\n\x0emcEnterpriseId\x18\x01 \x01(\x05\x12\x18\n\x10mcEnterpriseName\x18\x02 \x01(\t\x12\x11\n\tmspNodeId\x18\x03 \x01(\x03\x12\x15\n\rnumberOfSeats\x18\x04 \x01(\x05\x12\x15\n\rnumberOfUsers\x18\x05 \x01(\x05\x12\x11\n\tproductId\x18\x06 \x01(\t\x12\x11\n\tisExpired\x18\x07 \x01(\x08\x12\x0f\n\x07treeKey\x18\x08 \x01(\t\x12\x15\n\rtree_key_role\x18\t \x01(\x03\x12\x14\n\x0c\x66ilePlanType\x18\n \x01(\t\x12(\n\x06\x61\x64\x64Ons\x18\x0b \x03(\x0b\x32\x18.Enterprise.LicenseAddOn\"R\n\x07MSPPool\x12\x11\n\tproductId\x18\x01 \x01(\t\x12\r\n\x05seats\x18\x02 \x01(\x05\x12\x16\n\x0e\x61vailableSeats\x18\x03 \x01(\x05\x12\r\n\x05stash\x18\x04 \x01(\x05\":\n\nMSPContact\x12\x14\n\x0c\x65nterpriseId\x18\x01 \x01(\x05\x12\x16\n\x0e\x65nterpriseName\x18\x02 \x01(\t\"\xa5\x01\n\x0cLicenseAddOn\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x0f\n\x07isTrial\x18\x03 \x01(\x08\x12\x12\n\nexpiration\x18\x04 \x01(\x03\x12\x0f\n\x07\x63reated\x18\x05 \x01(\x03\x12\r\n\x05seats\x18\x06 \x01(\x05\x12\x16\n\x0e\x61\x63tivationTime\x18\x07 \x01(\x03\x12\x19\n\x11includedInProduct\x18\x08 \x01(\x08\"D\n\tMCDefault\x12\x11\n\tmcProduct\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x64\x64Ons\x18\x02 \x03(\t\x12\x14\n\x0c\x66ilePlanType\x18\x03 \x01(\t\"\xd2\x01\n\nMSPPermits\x12\x12\n\nrestricted\x18\x01 \x01(\x08\x12\x1a\n\x12maxAllowedLicenses\x18\x02 \x01(\x05\x12\x19\n\x11\x61llowedMcProducts\x18\x03 \x03(\t\x12\x15\n\rallowedAddOns\x18\x04 \x03(\t\x12\x17\n\x0fmaxFilePlanType\x18\x05 \x01(\t\x12\x1e\n\x16\x61llowUnlimitedLicenses\x18\x06 \x01(\x08\x12)\n\nmcDefaults\x18\x07 \x03(\x0b\x32\x15.Enterprise.MCDefault\"\xa0\x04\n\x07License\x12\x0c\n\x04paid\x18\x01 \x01(\x08\x12\x15\n\rnumberOfSeats\x18\x02 \x01(\x05\x12\x12\n\nexpiration\x18\x03 \x01(\x03\x12\x14\n\x0clicenseKeyId\x18\x04 \x01(\x05\x12\x15\n\rproductTypeId\x18\x05 \x01(\x05\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x1b\n\x13\x65nterpriseLicenseId\x18\x07 \x01(\x03\x12\x16\n\x0eseatsAllocated\x18\x08 \x01(\x05\x12\x14\n\x0cseatsPending\x18\t \x01(\x05\x12\x0c\n\x04tier\x18\n \x01(\x05\x12\x16\n\x0e\x66ilePlanTypeId\x18\x0b \x01(\x05\x12\x10\n\x08maxBytes\x18\x0c \x01(\x03\x12\x19\n\x11storageExpiration\x18\r \x01(\x03\x12\x15\n\rlicenseStatus\x18\x0e \x01(\t\x12$\n\x07mspPool\x18\x0f \x03(\x0b\x32\x13.Enterprise.MSPPool\x12)\n\tmanagedBy\x18\x10 \x01(\x0b\x32\x16.Enterprise.MSPContact\x12(\n\x06\x61\x64\x64Ons\x18\x11 \x03(\x0b\x32\x18.Enterprise.LicenseAddOn\x12\x17\n\x0fnextBillingDate\x18\x12 \x01(\x03\x12\x17\n\x0fhasMSPLegacyLog\x18\x13 \x01(\x08\x12*\n\nmspPermits\x18\x14 \x01(\x0b\x32\x16.Enterprise.MSPPermits\x12\x13\n\x0b\x64istributor\x18\x15 \x01(\x08\"n\n\x06\x42ridge\x12\x10\n\x08\x62ridgeId\x18\x01 \x01(\x03\x12\x0e\n\x06nodeId\x18\x02 \x01(\x03\x12\x18\n\x10wanIpEnforcement\x18\x03 \x01(\t\x12\x18\n\x10lanIpEnforcement\x18\x04 \x01(\t\x12\x0e\n\x06status\x18\x05 \x01(\t\"t\n\x04Scim\x12\x0e\n\x06scimId\x18\x01 \x01(\x03\x12\x0e\n\x06nodeId\x18\x02 \x01(\x03\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x12\n\nlastSynced\x18\x04 \x01(\x03\x12\x12\n\nrolePrefix\x18\x05 \x01(\t\x12\x14\n\x0cuniqueGroups\x18\x06 \x01(\x08\"L\n\x0e\x45mailProvision\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0e\n\x06nodeId\x18\x02 \x01(\x03\x12\x0e\n\x06\x64omain\x18\x03 \x01(\t\x12\x0e\n\x06method\x18\x04 \x01(\t\"R\n\nQueuedTeam\x12\x0f\n\x07teamUid\x18\x01 \x01(\x0c\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06nodeId\x18\x03 \x01(\x03\x12\x15\n\rencryptedData\x18\x04 \x01(\t\"0\n\x0eQueuedTeamUser\x12\x0f\n\x07teamUid\x18\x01 \x01(\x0c\x12\r\n\x05users\x18\x02 \x03(\x03\"\x91\x01\n\nSsoService\x12\x1c\n\x14ssoServiceProviderId\x18\x01 \x01(\x03\x12\x0e\n\x06nodeId\x18\x02 \x01(\x03\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0e\n\x06sp_url\x18\x04 \x01(\t\x12\x16\n\x0einviteNewUsers\x18\x05 \x01(\x08\x12\x0e\n\x06\x61\x63tive\x18\x06 \x01(\x08\x12\x0f\n\x07isCloud\x18\x07 \x01(\x08\"1\n\x10ReportFilterUser\x12\x0e\n\x06userId\x18\x01 \x01(\x05\x12\r\n\x05\x65mail\x18\x02 \x01(\t\"\x97\x02\n\x1d\x44\x65viceRequestForAdminApproval\x12\x10\n\x08\x64\x65viceId\x18\x01 \x01(\x03\x12\x18\n\x10\x65nterpriseUserId\x18\x02 \x01(\x03\x12\x1c\n\x14\x65ncryptedDeviceToken\x18\x03 \x01(\x0c\x12\x17\n\x0f\x64\x65vicePublicKey\x18\x04 \x01(\x0c\x12\x12\n\ndeviceName\x18\x05 \x01(\t\x12\x15\n\rclientVersion\x18\x06 \x01(\t\x12\x12\n\ndeviceType\x18\x07 \x01(\t\x12\x0c\n\x04\x64\x61te\x18\x08 \x01(\x03\x12\x11\n\tipAddress\x18\t \x01(\t\x12\x10\n\x08location\x18\n \x01(\t\x12\r\n\x05\x65mail\x18\x0b \x01(\t\x12\x12\n\naccountUid\x18\x0c \x01(\x0c\"`\n\x0e\x45nterpriseData\x12\x30\n\x06\x65ntity\x18\x01 \x01(\x0e\x32 .Enterprise.EnterpriseDataEntity\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\x08\x12\x0c\n\x04\x64\x61ta\x18\x03 \x03(\x0c\"\xd0\x01\n\x16\x45nterpriseDataResponse\x12\x19\n\x11\x63ontinuationToken\x18\x01 \x01(\x0c\x12\x0f\n\x07hasMore\x18\x02 \x01(\x08\x12,\n\x0b\x63\x61\x63heStatus\x18\x03 \x01(\x0e\x32\x17.Enterprise.CacheStatus\x12(\n\x04\x64\x61ta\x18\x04 \x03(\x0b\x32\x1a.Enterprise.EnterpriseData\x12\x32\n\x0bgeneralData\x18\x05 \x01(\x0b\x32\x1d.Enterprise.GeneralDataEntity\"*\n\rBackupRequest\x12\x19\n\x11\x63ontinuationToken\x18\x01 \x01(\x0c\"\x98\x01\n\x0c\x42\x61\x63kupRecord\x12\x0e\n\x06userId\x18\x01 \x01(\x05\x12\x11\n\trecordUid\x18\x02 \x01(\x0c\x12\x0b\n\x03key\x18\x03 \x01(\x0c\x12*\n\x07keyType\x18\x04 \x01(\x0e\x32\x19.Enterprise.BackupKeyType\x12\x0f\n\x07version\x18\x05 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\x0c\x12\r\n\x05\x65xtra\x18\x07 \x01(\x0c\".\n\tBackupKey\x12\x0e\n\x06userId\x18\x01 \x01(\x05\x12\x11\n\tbackupKey\x18\x02 \x01(\x0c\"\x8d\x02\n\nBackupUser\x12\x0e\n\x06userId\x18\x01 \x01(\x05\x12\x10\n\x08userName\x18\x02 \x01(\t\x12\x0f\n\x07\x64\x61taKey\x18\x03 \x01(\x0c\x12\x36\n\x0b\x64\x61taKeyType\x18\x04 \x01(\x0e\x32!.Enterprise.BackupUserDataKeyType\x12\x12\n\nprivateKey\x18\x05 \x01(\x0c\x12\x0f\n\x07treeKey\x18\x06 \x01(\x0c\x12.\n\x0btreeKeyType\x18\x07 \x01(\x0e\x32\x19.Enterprise.BackupKeyType\x12)\n\nbackupKeys\x18\x08 \x03(\x0b\x32\x15.Enterprise.BackupKey\x12\x14\n\x0cprivateECKey\x18\t \x01(\x0c\"\x9e\x01\n\x0e\x42\x61\x63kupResponse\x12\x1f\n\x17\x65nterpriseEccPrivateKey\x18\x01 \x01(\x0c\x12%\n\x05users\x18\x02 \x03(\x0b\x32\x16.Enterprise.BackupUser\x12)\n\x07records\x18\x03 \x03(\x0b\x32\x18.Enterprise.BackupRecord\x12\x19\n\x11\x63ontinuationToken\x18\x04 \x01(\x0c\"e\n\nBackupFile\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x11\n\tbackupUid\x18\x02 \x01(\x0c\x12\x10\n\x08\x66ileName\x18\x03 \x01(\t\x12\x0f\n\x07\x63reated\x18\x04 \x01(\x03\x12\x13\n\x0b\x64ownloadUrl\x18\x05 \x01(\t\"8\n\x0f\x42\x61\x63kupsResponse\x12%\n\x05\x66iles\x18\x01 \x03(\x0b\x32\x16.Enterprise.BackupFile\".\n\x1cGetEnterpriseDataKeysRequest\x12\x0e\n\x06roleId\x18\x01 \x03(\x03\"\xff\x01\n\x1dGetEnterpriseDataKeysResponse\x12:\n\x12reEncryptedRoleKey\x18\x01 \x03(\x0b\x32\x1e.Enterprise.ReEncryptedRoleKey\x12$\n\x07roleKey\x18\x02 \x03(\x0b\x32\x13.Enterprise.RoleKey\x12\"\n\x06mspKey\x18\x03 \x01(\x0b\x32\x12.Enterprise.MspKey\x12\x32\n\x0e\x65nterpriseKeys\x18\x04 \x01(\x0b\x32\x1a.Enterprise.EnterpriseKeys\x12$\n\x07treeKey\x18\x05 \x01(\x0b\x32\x13.Enterprise.TreeKey\"^\n\x07RoleKey\x12\x0e\n\x06roleId\x18\x01 \x01(\x03\x12\x14\n\x0c\x65ncryptedKey\x18\x02 \x01(\t\x12-\n\x07keyType\x18\x03 \x01(\x0e\x32\x1c.Enterprise.EncryptedKeyType\"d\n\x06MspKey\x12\x1b\n\x13\x65ncryptedMspTreeKey\x18\x01 \x01(\t\x12=\n\x17\x65ncryptedMspTreeKeyType\x18\x02 \x01(\x0e\x32\x1c.Enterprise.EncryptedKeyType\"|\n\x0e\x45nterpriseKeys\x12\x14\n\x0crsaPublicKey\x18\x01 \x01(\x0c\x12\x1e\n\x16rsaEncryptedPrivateKey\x18\x02 \x01(\x0c\x12\x14\n\x0c\x65\x63\x63PublicKey\x18\x03 \x01(\x0c\x12\x1e\n\x16\x65\x63\x63\x45ncryptedPrivateKey\x18\x04 \x01(\x0c\"H\n\x07TreeKey\x12\x0f\n\x07treeKey\x18\x01 \x01(\t\x12,\n\tkeyTypeId\x18\x02 \x01(\x0e\x32\x19.Enterprise.BackupKeyType\"E\n\x14SharedRecordResponse\x12-\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x1d.Enterprise.SharedRecordEvent\"p\n\x11SharedRecordEvent\x12\x11\n\trecordUid\x18\x01 \x01(\x0c\x12\x10\n\x08userName\x18\x02 \x01(\t\x12\x0f\n\x07\x63\x61nEdit\x18\x03 \x01(\x08\x12\x12\n\ncanReshare\x18\x04 \x01(\x08\x12\x11\n\tshareFrom\x18\x05 \x01(\x05\".\n\x1cSetRestrictVisibilityRequest\x12\x0e\n\x06nodeId\x18\x01 \x01(\x03\"\xd0\x01\n\x0eUserAddRequest\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x01(\x03\x12\x0e\n\x06nodeId\x18\x02 \x01(\x03\x12\x15\n\rencryptedData\x18\x03 \x01(\x0c\x12-\n\x07keyType\x18\x04 \x01(\x0e\x32\x1c.Enterprise.EncryptedKeyType\x12\x10\n\x08\x66ullName\x18\x05 \x01(\t\x12\x10\n\x08jobTitle\x18\x06 \x01(\t\x12\r\n\x05\x65mail\x18\x07 \x01(\t\x12\x1b\n\x13suppressEmailInvite\x18\x08 \x01(\x08\":\n\x11UserUpdateRequest\x12%\n\x05users\x18\x01 \x03(\x0b\x32\x16.Enterprise.UserUpdate\"\xaf\x01\n\nUserUpdate\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x01(\x03\x12\x0e\n\x06nodeId\x18\x02 \x01(\x03\x12\x15\n\rencryptedData\x18\x03 \x01(\x0c\x12-\n\x07keyType\x18\x04 \x01(\x0e\x32\x1c.Enterprise.EncryptedKeyType\x12\x10\n\x08\x66ullName\x18\x05 \x01(\t\x12\x10\n\x08jobTitle\x18\x06 \x01(\t\x12\r\n\x05\x65mail\x18\x07 \x01(\t\"A\n\x12UserUpdateResponse\x12+\n\x05users\x18\x01 \x03(\x0b\x32\x1c.Enterprise.UserUpdateResult\"Z\n\x10UserUpdateResult\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x01(\x03\x12,\n\x06status\x18\x02 \x01(\x0e\x32\x1c.Enterprise.UserUpdateStatus\"J\n\x1d\x43omplianceRecordOwnersRequest\x12\x0f\n\x07nodeIds\x18\x01 \x03(\x03\x12\x18\n\x10includeNonShared\x18\x02 \x01(\x08\"O\n\x1e\x43omplianceRecordOwnersResponse\x12-\n\x0crecordOwners\x18\x01 \x03(\x0b\x32\x17.Enterprise.RecordOwner\"7\n\x0bRecordOwner\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x01(\x03\x12\x0e\n\x06shared\x18\x02 \x01(\x08\"\xa6\x01\n PreliminaryComplianceDataRequest\x12\x19\n\x11\x65nterpriseUserIds\x18\x01 \x03(\x03\x12\x18\n\x10includeNonShared\x18\x02 \x01(\x08\x12\x19\n\x11\x63ontinuationToken\x18\x03 \x01(\x0c\x12\x32\n*includeTotalMatchingRecordsInFirstResponse\x18\x04 \x01(\x08\"\x9f\x01\n!PreliminaryComplianceDataResponse\x12\x30\n\rauditUserData\x18\x01 \x03(\x0b\x32\x19.Enterprise.AuditUserData\x12\x19\n\x11\x63ontinuationToken\x18\x02 \x01(\x0c\x12\x0f\n\x07hasMore\x18\x03 \x01(\x08\x12\x1c\n\x14totalMatchingRecords\x18\x04 \x01(\x05\"K\n\x0f\x41uditUserRecord\x12\x11\n\trecordUid\x18\x01 \x01(\x0c\x12\x15\n\rencryptedData\x18\x02 \x01(\x0c\x12\x0e\n\x06shared\x18\x03 \x01(\x08\"\x8d\x01\n\rAuditUserData\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x01(\x03\x12\x35\n\x10\x61uditUserRecords\x18\x02 \x03(\x0b\x32\x1b.Enterprise.AuditUserRecord\x12+\n\x06status\x18\x03 \x01(\x0e\x32\x1b.Enterprise.AuditUserStatus\"\x7f\n\x17\x43omplianceReportFilters\x12\x14\n\x0crecordTitles\x18\x01 \x03(\t\x12\x12\n\nrecordUids\x18\x02 \x03(\x0c\x12\x11\n\tjobTitles\x18\x03 \x03(\x03\x12\x0c\n\x04urls\x18\x04 \x03(\t\x12\x19\n\x11\x65nterpriseUserIds\x18\x05 \x03(\x03\"\x7f\n\x17\x43omplianceReportRequest\x12<\n\x13\x63omplianceReportRun\x18\x01 \x01(\x0b\x32\x1f.Enterprise.ComplianceReportRun\x12\x12\n\nreportName\x18\x02 \x01(\t\x12\x12\n\nsaveReport\x18\x03 \x01(\x08\"\x85\x01\n\x13\x43omplianceReportRun\x12N\n\x17reportCriteriaAndFilter\x18\x01 \x01(\x0b\x32-.Enterprise.ComplianceReportCriteriaAndFilter\x12\r\n\x05users\x18\x02 \x03(\x03\x12\x0f\n\x07records\x18\x03 \x03(\x0c\"\xfc\x01\n!ComplianceReportCriteriaAndFilter\x12\x0e\n\x06nodeId\x18\x01 \x01(\x03\x12\x13\n\x0b\x63riteriaUid\x18\x02 \x01(\x0c\x12\x14\n\x0c\x63riteriaName\x18\x03 \x01(\t\x12\x36\n\x08\x63riteria\x18\x04 \x01(\x0b\x32$.Enterprise.ComplianceReportCriteria\x12\x33\n\x07\x66ilters\x18\x05 \x03(\x0b\x32\".Enterprise.ComplianceReportFilter\x12\x14\n\x0clastModified\x18\x06 \x01(\x03\x12\x19\n\x11nodeEncryptedData\x18\x07 \x01(\x0c\"b\n\x18\x43omplianceReportCriteria\x12\x11\n\tjobTitles\x18\x01 \x03(\t\x12\x19\n\x11\x65nterpriseUserIds\x18\x02 \x03(\x03\x12\x18\n\x10includeNonShared\x18\x03 \x01(\x08\"x\n\x16\x43omplianceReportFilter\x12\x14\n\x0crecordTitles\x18\x01 \x03(\t\x12\x12\n\nrecordUids\x18\x02 \x03(\x0c\x12\x11\n\tjobTitles\x18\x03 \x03(\t\x12\x0c\n\x04urls\x18\x04 \x03(\t\x12\x13\n\x0brecordTypes\x18\x05 \x03(\t\"\xa1\x05\n\x18\x43omplianceReportResponse\x12\x15\n\rdateGenerated\x18\x01 \x01(\x03\x12\x15\n\rrunByUserName\x18\x02 \x01(\t\x12\x12\n\nreportName\x18\x03 \x01(\t\x12\x11\n\treportUid\x18\x04 \x01(\x0c\x12<\n\x13\x63omplianceReportRun\x18\x05 \x01(\x0b\x32\x1f.Enterprise.ComplianceReportRun\x12-\n\x0cuserProfiles\x18\x06 \x03(\x0b\x32\x17.Enterprise.UserProfile\x12)\n\nauditTeams\x18\x07 \x03(\x0b\x32\x15.Enterprise.AuditTeam\x12-\n\x0c\x61uditRecords\x18\x08 \x03(\x0b\x32\x17.Enterprise.AuditRecord\x12+\n\x0buserRecords\x18\t \x03(\x0b\x32\x16.Enterprise.UserRecord\x12;\n\x13sharedFolderRecords\x18\n \x03(\x0b\x32\x1e.Enterprise.SharedFolderRecord\x12\x37\n\x11sharedFolderUsers\x18\x0b \x03(\x0b\x32\x1c.Enterprise.SharedFolderUser\x12\x37\n\x11sharedFolderTeams\x18\x0c \x03(\x0b\x32\x1c.Enterprise.SharedFolderTeam\x12\x31\n\x0e\x61uditTeamUsers\x18\r \x03(\x0b\x32\x19.Enterprise.AuditTeamUser\x12)\n\nauditRoles\x18\x0e \x03(\x0b\x32\x15.Enterprise.AuditRole\x12/\n\rlinkedRecords\x18\x0f \x03(\x0b\x32\x18.Enterprise.LinkedRecord\"\x81\x01\n\x0b\x41uditRecord\x12\x11\n\trecordUid\x18\x01 \x01(\x0c\x12\x11\n\tauditData\x18\x02 \x01(\x0c\x12\x16\n\x0ehasAttachments\x18\x03 \x01(\x08\x12\x0f\n\x07inTrash\x18\x04 \x01(\x08\x12\x10\n\x08treeLeft\x18\x05 \x01(\x05\x12\x11\n\ttreeRight\x18\x06 \x01(\x05\"\x80\x02\n\tAuditRole\x12\x0e\n\x06roleId\x18\x01 \x01(\x03\x12\x15\n\rencryptedData\x18\x02 \x01(\x0c\x12&\n\x1erestrictShareOutsideEnterprise\x18\x03 \x01(\x08\x12\x18\n\x10restrictShareAll\x18\x04 \x01(\x08\x12\"\n\x1arestrictShareOfAttachments\x18\x05 \x01(\x08\x12)\n!restrictMaskPasswordsWhileEditing\x18\x06 \x01(\x08\x12;\n\x13roleNodeManagements\x18\x07 \x03(\x0b\x32\x1e.Enterprise.RoleNodeManagement\"^\n\x12RoleNodeManagement\x12\x10\n\x08treeLeft\x18\x01 \x01(\x05\x12\x11\n\ttreeRight\x18\x02 \x01(\x05\x12\x0f\n\x07\x63\x61scade\x18\x03 \x01(\x08\x12\x12\n\nprivileges\x18\x04 \x01(\x05\"k\n\x0bUserProfile\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x01(\x03\x12\x10\n\x08\x66ullName\x18\x02 \x01(\t\x12\x10\n\x08jobTitle\x18\x03 \x01(\t\x12\r\n\x05\x65mail\x18\x04 \x01(\t\x12\x0f\n\x07roleIds\x18\x05 \x03(\x03\"=\n\x10RecordPermission\x12\x11\n\trecordUid\x18\x01 \x01(\x0c\x12\x16\n\x0epermissionBits\x18\x02 \x01(\x05\"_\n\nUserRecord\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x01(\x03\x12\x37\n\x11recordPermissions\x18\x02 \x03(\x0b\x32\x1c.Enterprise.RecordPermission\"[\n\tAuditTeam\x12\x0f\n\x07teamUid\x18\x01 \x01(\x0c\x12\x10\n\x08teamName\x18\x02 \x01(\t\x12\x14\n\x0crestrictEdit\x18\x03 \x01(\x08\x12\x15\n\rrestrictShare\x18\x04 \x01(\x08\";\n\rAuditTeamUser\x12\x0f\n\x07teamUid\x18\x01 \x01(\x0c\x12\x19\n\x11\x65nterpriseUserIds\x18\x02 \x03(\x03\"\x9f\x01\n\x12SharedFolderRecord\x12\x17\n\x0fsharedFolderUid\x18\x01 \x01(\x0c\x12\x37\n\x11recordPermissions\x18\x02 \x03(\x0b\x32\x1c.Enterprise.RecordPermission\x12\x37\n\x11shareAdminRecords\x18\x03 \x03(\x0b\x32\x1c.Enterprise.ShareAdminRecord\"M\n\x10ShareAdminRecord\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x01(\x03\x12\x1f\n\x17recordPermissionIndexes\x18\x02 \x03(\x05\"F\n\x10SharedFolderUser\x12\x17\n\x0fsharedFolderUid\x18\x01 \x01(\x0c\x12\x19\n\x11\x65nterpriseUserIds\x18\x02 \x03(\x03\"=\n\x10SharedFolderTeam\x12\x17\n\x0fsharedFolderUid\x18\x01 \x01(\x0c\x12\x10\n\x08teamUids\x18\x02 \x03(\x0c\"/\n\x1aGetComplianceReportRequest\x12\x11\n\treportUid\x18\x01 \x01(\x0c\"2\n\x1bGetComplianceReportResponse\x12\x13\n\x0b\x64ownloadUrl\x18\x01 \x01(\t\"6\n\x1f\x43omplianceReportCriteriaRequest\x12\x13\n\x0b\x63riteriaUid\x18\x01 \x01(\x0c\";\n$SaveComplianceReportCriteriaResponse\x12\x13\n\x0b\x63riteriaUid\x18\x01 \x01(\x0c\"4\n\x0cLinkedRecord\x12\x10\n\x08ownerUid\x18\x01 \x01(\x0c\x12\x12\n\nrecordUids\x18\x02 \x03(\x0c\"W\n\x17GetSharingAdminsRequest\x12\x17\n\x0fsharedFolderUid\x18\x01 \x01(\x0c\x12\x11\n\trecordUid\x18\x02 \x01(\x0c\x12\x10\n\x08username\x18\x03 \x01(\t\"\xc5\x01\n\x0eUserProfileExt\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x10\n\x08\x66ullName\x18\x02 \x01(\t\x12\x10\n\x08jobTitle\x18\x03 \x01(\t\x12\x14\n\x0cisMSPMCAdmin\x18\x04 \x01(\x08\x12\x18\n\x10isInSharedFolder\x18\x05 \x01(\x08\x12&\n\x1eisShareAdminForRequestedObject\x18\x06 \x01(\x08\x12(\n isShareAdminForSharedFolderOwner\x18\x07 \x01(\x08\"O\n\x18GetSharingAdminsResponse\x12\x33\n\x0fuserProfileExts\x18\x01 \x03(\x0b\x32\x1a.Enterprise.UserProfileExt\"_\n\x1eTeamsEnterpriseUsersAddRequest\x12=\n\x05teams\x18\x01 \x03(\x0b\x32..Enterprise.TeamsEnterpriseUsersAddTeamRequest\"t\n\"TeamsEnterpriseUsersAddTeamRequest\x12\x0f\n\x07teamUid\x18\x01 \x01(\x0c\x12=\n\x05users\x18\x02 \x03(\x0b\x32..Enterprise.TeamsEnterpriseUsersAddUserRequest\"{\n\"TeamsEnterpriseUsersAddUserRequest\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x01(\x03\x12*\n\x08userType\x18\x02 \x01(\x0e\x32\x18.Enterprise.TeamUserType\x12\x0f\n\x07teamKey\x18\x03 \x01(\t\"s\n\x1fTeamsEnterpriseUsersAddResponse\x12>\n\x05teams\x18\x01 \x03(\x0b\x32/.Enterprise.TeamsEnterpriseUsersAddTeamResponse\x12\x10\n\x08revision\x18\x02 \x01(\x03\"\xc4\x01\n#TeamsEnterpriseUsersAddTeamResponse\x12\x0f\n\x07teamUid\x18\x01 \x01(\x0c\x12>\n\x05users\x18\x02 \x03(\x0b\x32/.Enterprise.TeamsEnterpriseUsersAddUserResponse\x12\x0f\n\x07success\x18\x03 \x01(\x08\x12\x0f\n\x07message\x18\x04 \x01(\t\x12\x12\n\nresultCode\x18\x05 \x01(\t\x12\x16\n\x0e\x61\x64\x64itionalInfo\x18\x06 \x01(\t\"\x9f\x01\n#TeamsEnterpriseUsersAddUserResponse\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x01(\x03\x12\x10\n\x08revision\x18\x02 \x01(\x03\x12\x0f\n\x07success\x18\x03 \x01(\x08\x12\x0f\n\x07message\x18\x04 \x01(\t\x12\x12\n\nresultCode\x18\x05 \x01(\t\x12\x16\n\x0e\x61\x64\x64itionalInfo\x18\x06 \x01(\t\"M\n\x0b\x44omainAlias\x12\x0e\n\x06\x64omain\x18\x01 \x01(\t\x12\r\n\x05\x61lias\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\x05\x12\x0f\n\x07message\x18\x04 \x01(\t\"B\n\x12\x44omainAliasRequest\x12,\n\x0b\x64omainAlias\x18\x01 \x03(\x0b\x32\x17.Enterprise.DomainAlias\"C\n\x13\x44omainAliasResponse\x12,\n\x0b\x64omainAlias\x18\x01 \x03(\x0b\x32\x17.Enterprise.DomainAlias\"m\n\x1f\x45nterpriseUsersProvisionRequest\x12\x33\n\x05users\x18\x01 \x03(\x0b\x32$.Enterprise.EnterpriseUsersProvision\x12\x15\n\rclientVersion\x18\x02 \x01(\t\"\xb6\x03\n\x18\x45nterpriseUsersProvision\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x01(\x03\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x0e\n\x06nodeId\x18\x03 \x01(\x03\x12\x15\n\rencryptedData\x18\x04 \x01(\t\x12-\n\x07keyType\x18\x05 \x01(\x0e\x32\x1c.Enterprise.EncryptedKeyType\x12\x10\n\x08\x66ullName\x18\x06 \x01(\t\x12\x10\n\x08jobTitle\x18\x07 \x01(\t\x12\x1e\n\x16\x65nterpriseUsersDataKey\x18\x08 \x01(\x0c\x12\x14\n\x0c\x61uthVerifier\x18\t \x01(\x0c\x12\x18\n\x10\x65ncryptionParams\x18\n \x01(\x0c\x12\x14\n\x0crsaPublicKey\x18\x0b \x01(\x0c\x12\x1e\n\x16rsaEncryptedPrivateKey\x18\x0c \x01(\x0c\x12\x14\n\x0c\x65\x63\x63PublicKey\x18\r \x01(\x0c\x12\x1e\n\x16\x65\x63\x63\x45ncryptedPrivateKey\x18\x0e \x01(\x0c\x12\x1c\n\x14\x65ncryptedDeviceToken\x18\x0f \x01(\x0c\x12\x1a\n\x12\x65ncryptedClientKey\x18\x10 \x01(\x0c\"_\n EnterpriseUsersProvisionResponse\x12;\n\x07results\x18\x01 \x03(\x0b\x32*.Enterprise.EnterpriseUsersProvisionResult\"q\n\x1e\x45nterpriseUsersProvisionResult\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x01(\x03\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x16\n\x0e\x61\x64\x64itionalInfo\x18\x04 \x01(\t\"a\n\x19\x45nterpriseUsersAddRequest\x12-\n\x05users\x18\x01 \x03(\x0b\x32\x1e.Enterprise.EnterpriseUsersAdd\x12\x15\n\rclientVersion\x18\x02 \x01(\t\"\xfc\x01\n\x12\x45nterpriseUsersAdd\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x01(\x03\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x0e\n\x06nodeId\x18\x03 \x01(\x03\x12\x15\n\rencryptedData\x18\x04 \x01(\t\x12-\n\x07keyType\x18\x05 \x01(\x0e\x32\x1c.Enterprise.EncryptedKeyType\x12\x10\n\x08\x66ullName\x18\x06 \x01(\t\x12\x10\n\x08jobTitle\x18\x07 \x01(\t\x12\x1b\n\x13suppressEmailInvite\x18\x08 \x01(\x08\x12\x15\n\rinviteeLocale\x18\t \x01(\t\x12\x0c\n\x04move\x18\n \x01(\x08\"\x9b\x01\n\x1a\x45nterpriseUsersAddResponse\x12\x35\n\x07results\x18\x01 \x03(\x0b\x32$.Enterprise.EnterpriseUsersAddResult\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x0f\n\x07message\x18\x04 \x01(\t\x12\x16\n\x0e\x61\x64\x64itionalInfo\x18\x05 \x01(\t\"\x96\x01\n\x18\x45nterpriseUsersAddResult\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x01(\x03\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x18\n\x10verificationCode\x18\x03 \x01(\t\x12\x0c\n\x04\x63ode\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\x12\x16\n\x0e\x61\x64\x64itionalInfo\x18\x06 \x01(\t\"\xb9\x01\n\x17UpdateMSPPermitsRequest\x12\x17\n\x0fmspEnterpriseId\x18\x01 \x01(\x05\x12\x1a\n\x12maxAllowedLicenses\x18\x02 \x01(\x05\x12\x19\n\x11\x61llowedMcProducts\x18\x03 \x03(\t\x12\x15\n\rallowedAddOns\x18\x04 \x03(\t\x12\x17\n\x0fmaxFilePlanType\x18\x05 \x01(\t\x12\x1e\n\x16\x61llowUnlimitedLicenses\x18\x06 \x01(\x08*\x1b\n\x07KeyType\x12\x07\n\x03RSA\x10\x00\x12\x07\n\x03\x45\x43\x43\x10\x01*=\n\x0e\x45nterpriseType\x12\x17\n\x13\x45NTERPRISE_STANDARD\x10\x00\x12\x12\n\x0e\x45NTERPRISE_MSP\x10\x01*\xe1\x03\n\x14\x45nterpriseDataEntity\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05NODES\x10\x01\x12\t\n\x05ROLES\x10\x02\x12\t\n\x05USERS\x10\x03\x12\t\n\x05TEAMS\x10\x04\x12\x0e\n\nTEAM_USERS\x10\x05\x12\x0e\n\nROLE_USERS\x10\x06\x12\x13\n\x0fROLE_PRIVILEGES\x10\x07\x12\x15\n\x11ROLE_ENFORCEMENTS\x10\x08\x12\x0e\n\nROLE_TEAMS\x10\t\x12\x0c\n\x08LICENSES\x10\n\x12\x11\n\rMANAGED_NODES\x10\x0b\x12\x15\n\x11MANAGED_COMPANIES\x10\x0c\x12\x0b\n\x07\x42RIDGES\x10\r\x12\t\n\x05SCIMS\x10\x0e\x12\x13\n\x0f\x45MAIL_PROVISION\x10\x0f\x12\x10\n\x0cQUEUED_TEAMS\x10\x10\x12\x15\n\x11QUEUED_TEAM_USERS\x10\x11\x12\x10\n\x0cSSO_SERVICES\x10\x12\x12\x17\n\x13REPORT_FILTER_USERS\x10\x13\x12&\n\"DEVICES_REQUEST_FOR_ADMIN_APPROVAL\x10\x14\x12\x10\n\x0cUSER_ALIASES\x10\x15\x12)\n%COMPLIANCE_REPORT_CRITERIA_AND_FILTER\x10\x16\x12\x16\n\x12\x43OMPLIANCE_REPORTS\x10\x17*\"\n\x0b\x43\x61\x63heStatus\x12\x08\n\x04KEEP\x10\x00\x12\t\n\x05\x43LEAR\x10\x01*\x93\x01\n\rBackupKeyType\x12\n\n\x06NO_KEY\x10\x00\x12\x19\n\x15\x45NCRYPTED_BY_DATA_KEY\x10\x01\x12\x1b\n\x17\x45NCRYPTED_BY_PUBLIC_KEY\x10\x02\x12\x1d\n\x19\x45NCRYPTED_BY_DATA_KEY_GCM\x10\x03\x12\x1f\n\x1b\x45NCRYPTED_BY_PUBLIC_KEY_ECC\x10\x04*:\n\x15\x42\x61\x63kupUserDataKeyType\x12\x07\n\x03OWN\x10\x00\x12\x18\n\x14SHARED_TO_ENTERPRISE\x10\x01*\xa5\x01\n\x10\x45ncryptedKeyType\x12\r\n\tKT_NO_KEY\x10\x00\x12\x1c\n\x18KT_ENCRYPTED_BY_DATA_KEY\x10\x01\x12\x1e\n\x1aKT_ENCRYPTED_BY_PUBLIC_KEY\x10\x02\x12 \n\x1cKT_ENCRYPTED_BY_DATA_KEY_GCM\x10\x03\x12\"\n\x1eKT_ENCRYPTED_BY_PUBLIC_KEY_ECC\x10\x04*\x95\x01\n\x12\x45nterpriseFlagType\x12\x0b\n\x07INVALID\x10\x00\x12\x1a\n\x16\x41LLOW_PERSONAL_LICENSE\x10\x01\x12\x18\n\x14SPECIAL_PROVISIONING\x10\x02\x12\x10\n\x0cRECORD_TYPES\x10\x03\x12\x13\n\x0fSECRETS_MANAGER\x10\x04\x12\x15\n\x11\x45NTERPRISE_LOCKED\x10\x05*E\n\x10UserUpdateStatus\x12\x12\n\x0eUSER_UPDATE_OK\x10\x00\x12\x1d\n\x19USER_UPDATE_ACCESS_DENIED\x10\x01*I\n\x0f\x41uditUserStatus\x12\x06\n\x02OK\x10\x00\x12\x11\n\rACCESS_DENIED\x10\x01\x12\x1b\n\x17NO_LONGER_IN_ENTERPRISE\x10\x02*3\n\x0cTeamUserType\x12\x08\n\x04USER\x10\x00\x12\t\n\x05\x41\x44MIN\x10\x01\x12\x0e\n\nADMIN_ONLY\x10\x02*e\n\rAppClientType\x12\x0c\n\x08NOT_USED\x10\x00\x12\x0b\n\x07GENERAL\x10\x01\x12%\n!DISCOVERY_AND_ROTATION_CONTROLLER\x10\x02\x12\x12\n\x0eKCM_CONTROLLER\x10\x03\x42&\n\x18\x63om.keepersecurity.protoB\nEnterpriseb\x06proto3')

_KEYTYPE = DESCRIPTOR.enum_types_by_name['KeyType']
KeyType = enum_type_wrapper.EnumTypeWrapper(_KEYTYPE)
_ENTERPRISETYPE = DESCRIPTOR.enum_types_by_name['EnterpriseType']
EnterpriseType = enum_type_wrapper.EnumTypeWrapper(_ENTERPRISETYPE)
_ENTERPRISEDATAENTITY = DESCRIPTOR.enum_types_by_name['EnterpriseDataEntity']
EnterpriseDataEntity = enum_type_wrapper.EnumTypeWrapper(_ENTERPRISEDATAENTITY)
_CACHESTATUS = DESCRIPTOR.enum_types_by_name['CacheStatus']
CacheStatus = enum_type_wrapper.EnumTypeWrapper(_CACHESTATUS)
_BACKUPKEYTYPE = DESCRIPTOR.enum_types_by_name['BackupKeyType']
BackupKeyType = enum_type_wrapper.EnumTypeWrapper(_BACKUPKEYTYPE)
_BACKUPUSERDATAKEYTYPE = DESCRIPTOR.enum_types_by_name['BackupUserDataKeyType']
BackupUserDataKeyType = enum_type_wrapper.EnumTypeWrapper(_BACKUPUSERDATAKEYTYPE)
_ENCRYPTEDKEYTYPE = DESCRIPTOR.enum_types_by_name['EncryptedKeyType']
EncryptedKeyType = enum_type_wrapper.EnumTypeWrapper(_ENCRYPTEDKEYTYPE)
_ENTERPRISEFLAGTYPE = DESCRIPTOR.enum_types_by_name['EnterpriseFlagType']
EnterpriseFlagType = enum_type_wrapper.EnumTypeWrapper(_ENTERPRISEFLAGTYPE)
_USERUPDATESTATUS = DESCRIPTOR.enum_types_by_name['UserUpdateStatus']
UserUpdateStatus = enum_type_wrapper.EnumTypeWrapper(_USERUPDATESTATUS)
_AUDITUSERSTATUS = DESCRIPTOR.enum_types_by_name['AuditUserStatus']
AuditUserStatus = enum_type_wrapper.EnumTypeWrapper(_AUDITUSERSTATUS)
_TEAMUSERTYPE = DESCRIPTOR.enum_types_by_name['TeamUserType']
TeamUserType = enum_type_wrapper.EnumTypeWrapper(_TEAMUSERTYPE)
_APPCLIENTTYPE = DESCRIPTOR.enum_types_by_name['AppClientType']
AppClientType = enum_type_wrapper.EnumTypeWrapper(_APPCLIENTTYPE)
RSA = 0
ECC = 1
ENTERPRISE_STANDARD = 0
ENTERPRISE_MSP = 1
UNKNOWN = 0
NODES = 1
ROLES = 2
USERS = 3
TEAMS = 4
TEAM_USERS = 5
ROLE_USERS = 6
ROLE_PRIVILEGES = 7
ROLE_ENFORCEMENTS = 8
ROLE_TEAMS = 9
LICENSES = 10
MANAGED_NODES = 11
MANAGED_COMPANIES = 12
BRIDGES = 13
SCIMS = 14
EMAIL_PROVISION = 15
QUEUED_TEAMS = 16
QUEUED_TEAM_USERS = 17
SSO_SERVICES = 18
REPORT_FILTER_USERS = 19
DEVICES_REQUEST_FOR_ADMIN_APPROVAL = 20
USER_ALIASES = 21
COMPLIANCE_REPORT_CRITERIA_AND_FILTER = 22
COMPLIANCE_REPORTS = 23
KEEP = 0
CLEAR = 1
NO_KEY = 0
ENCRYPTED_BY_DATA_KEY = 1
ENCRYPTED_BY_PUBLIC_KEY = 2
ENCRYPTED_BY_DATA_KEY_GCM = 3
ENCRYPTED_BY_PUBLIC_KEY_ECC = 4
OWN = 0
SHARED_TO_ENTERPRISE = 1
KT_NO_KEY = 0
KT_ENCRYPTED_BY_DATA_KEY = 1
KT_ENCRYPTED_BY_PUBLIC_KEY = 2
KT_ENCRYPTED_BY_DATA_KEY_GCM = 3
KT_ENCRYPTED_BY_PUBLIC_KEY_ECC = 4
INVALID = 0
ALLOW_PERSONAL_LICENSE = 1
SPECIAL_PROVISIONING = 2
RECORD_TYPES = 3
SECRETS_MANAGER = 4
ENTERPRISE_LOCKED = 5
USER_UPDATE_OK = 0
USER_UPDATE_ACCESS_DENIED = 1
OK = 0
ACCESS_DENIED = 1
NO_LONGER_IN_ENTERPRISE = 2
USER = 0
ADMIN = 1
ADMIN_ONLY = 2
NOT_USED = 0
GENERAL = 1
DISCOVERY_AND_ROTATION_CONTROLLER = 2
KCM_CONTROLLER = 3


_ENTERPRISEKEYPAIRREQUEST = DESCRIPTOR.message_types_by_name['EnterpriseKeyPairRequest']
_GETTEAMMEMBERREQUEST = DESCRIPTOR.message_types_by_name['GetTeamMemberRequest']
_ENTERPRISEUSER = DESCRIPTOR.message_types_by_name['EnterpriseUser']
_GETTEAMMEMBERRESPONSE = DESCRIPTOR.message_types_by_name['GetTeamMemberResponse']
_ENTERPRISEUSERIDS = DESCRIPTOR.message_types_by_name['EnterpriseUserIds']
_ENTERPRISEPERSONALACCOUNT = DESCRIPTOR.message_types_by_name['EnterprisePersonalAccount']
_ENCRYPTEDTEAMKEYREQUEST = DESCRIPTOR.message_types_by_name['EncryptedTeamKeyRequest']
_REENCRYPTEDDATA = DESCRIPTOR.message_types_by_name['ReEncryptedData']
_REENCRYPTEDROLEKEY = DESCRIPTOR.message_types_by_name['ReEncryptedRoleKey']
_NODETOMANAGEDCOMPANYREQUEST = DESCRIPTOR.message_types_by_name['NodeToManagedCompanyRequest']
_ROLETEAM = DESCRIPTOR.message_types_by_name['RoleTeam']
_ROLETEAMS = DESCRIPTOR.message_types_by_name['RoleTeams']
_ENTERPRISEREGISTRATION = DESCRIPTOR.message_types_by_name['EnterpriseRegistration']
_DOMAINPASSWORDRULESREQUEST = DESCRIPTOR.message_types_by_name['DomainPasswordRulesRequest']
_DOMAINPASSWORDRULESFIELDS = DESCRIPTOR.message_types_by_name['DomainPasswordRulesFields']
_LOGINTOMCREQUEST = DESCRIPTOR.message_types_by_name['LoginToMcRequest']
_LOGINTOMCRESPONSE = DESCRIPTOR.message_types_by_name['LoginToMcResponse']
_DOMAINPASSWORDRULESRESPONSE = DESCRIPTOR.message_types_by_name['DomainPasswordRulesResponse']
_APPROVEUSERDEVICEREQUEST = DESCRIPTOR.message_types_by_name['ApproveUserDeviceRequest']
_APPROVEUSERDEVICERESPONSE = DESCRIPTOR.message_types_by_name['ApproveUserDeviceResponse']
_APPROVEUSERDEVICESREQUEST = DESCRIPTOR.message_types_by_name['ApproveUserDevicesRequest']
_APPROVEUSERDEVICESRESPONSE = DESCRIPTOR.message_types_by_name['ApproveUserDevicesResponse']
_ENTERPRISEUSERDATAKEY = DESCRIPTOR.message_types_by_name['EnterpriseUserDataKey']
_ENTERPRISEUSERDATAKEYS = DESCRIPTOR.message_types_by_name['EnterpriseUserDataKeys']
_ENTERPRISEDATAREQUEST = DESCRIPTOR.message_types_by_name['EnterpriseDataRequest']
_SPECIALPROVISIONING = DESCRIPTOR.message_types_by_name['SpecialProvisioning']
_GENERALDATAENTITY = DESCRIPTOR.message_types_by_name['GeneralDataEntity']
_NODE = DESCRIPTOR.message_types_by_name['Node']
_ROLE = DESCRIPTOR.message_types_by_name['Role']
_USER = DESCRIPTOR.message_types_by_name['User']
_USERALIAS = DESCRIPTOR.message_types_by_name['UserAlias']
_COMPLIANCEREPORTMETADATA = DESCRIPTOR.message_types_by_name['ComplianceReportMetaData']
_MANAGEDNODE = DESCRIPTOR.message_types_by_name['ManagedNode']
_USERMANAGEDNODE = DESCRIPTOR.message_types_by_name['UserManagedNode']
_USERPRIVILEGE = DESCRIPTOR.message_types_by_name['UserPrivilege']
_ROLEUSER = DESCRIPTOR.message_types_by_name['RoleUser']
_ROLEPRIVILEGE = DESCRIPTOR.message_types_by_name['RolePrivilege']
_ROLEENFORCEMENT = DESCRIPTOR.message_types_by_name['RoleEnforcement']
_TEAM = DESCRIPTOR.message_types_by_name['Team']
_TEAMUSER = DESCRIPTOR.message_types_by_name['TeamUser']
_GETDISTRIBUTORINFORESPONSE = DESCRIPTOR.message_types_by_name['GetDistributorInfoResponse']
_DISTRIBUTOR = DESCRIPTOR.message_types_by_name['Distributor']
_MSPINFO = DESCRIPTOR.message_types_by_name['MspInfo']
_MANAGEDCOMPANY = DESCRIPTOR.message_types_by_name['ManagedCompany']
_MSPPOOL = DESCRIPTOR.message_types_by_name['MSPPool']
_MSPCONTACT = DESCRIPTOR.message_types_by_name['MSPContact']
_LICENSEADDON = DESCRIPTOR.message_types_by_name['LicenseAddOn']
_MCDEFAULT = DESCRIPTOR.message_types_by_name['MCDefault']
_MSPPERMITS = DESCRIPTOR.message_types_by_name['MSPPermits']
_LICENSE = DESCRIPTOR.message_types_by_name['License']
_BRIDGE = DESCRIPTOR.message_types_by_name['Bridge']
_SCIM = DESCRIPTOR.message_types_by_name['Scim']
_EMAILPROVISION = DESCRIPTOR.message_types_by_name['EmailProvision']
_QUEUEDTEAM = DESCRIPTOR.message_types_by_name['QueuedTeam']
_QUEUEDTEAMUSER = DESCRIPTOR.message_types_by_name['QueuedTeamUser']
_SSOSERVICE = DESCRIPTOR.message_types_by_name['SsoService']
_REPORTFILTERUSER = DESCRIPTOR.message_types_by_name['ReportFilterUser']
_DEVICEREQUESTFORADMINAPPROVAL = DESCRIPTOR.message_types_by_name['DeviceRequestForAdminApproval']
_ENTERPRISEDATA = DESCRIPTOR.message_types_by_name['EnterpriseData']
_ENTERPRISEDATARESPONSE = DESCRIPTOR.message_types_by_name['EnterpriseDataResponse']
_BACKUPREQUEST = DESCRIPTOR.message_types_by_name['BackupRequest']
_BACKUPRECORD = DESCRIPTOR.message_types_by_name['BackupRecord']
_BACKUPKEY = DESCRIPTOR.message_types_by_name['BackupKey']
_BACKUPUSER = DESCRIPTOR.message_types_by_name['BackupUser']
_BACKUPRESPONSE = DESCRIPTOR.message_types_by_name['BackupResponse']
_BACKUPFILE = DESCRIPTOR.message_types_by_name['BackupFile']
_BACKUPSRESPONSE = DESCRIPTOR.message_types_by_name['BackupsResponse']
_GETENTERPRISEDATAKEYSREQUEST = DESCRIPTOR.message_types_by_name['GetEnterpriseDataKeysRequest']
_GETENTERPRISEDATAKEYSRESPONSE = DESCRIPTOR.message_types_by_name['GetEnterpriseDataKeysResponse']
_ROLEKEY = DESCRIPTOR.message_types_by_name['RoleKey']
_MSPKEY = DESCRIPTOR.message_types_by_name['MspKey']
_ENTERPRISEKEYS = DESCRIPTOR.message_types_by_name['EnterpriseKeys']
_TREEKEY = DESCRIPTOR.message_types_by_name['TreeKey']
_SHAREDRECORDRESPONSE = DESCRIPTOR.message_types_by_name['SharedRecordResponse']
_SHAREDRECORDEVENT = DESCRIPTOR.message_types_by_name['SharedRecordEvent']
_SETRESTRICTVISIBILITYREQUEST = DESCRIPTOR.message_types_by_name['SetRestrictVisibilityRequest']
_USERADDREQUEST = DESCRIPTOR.message_types_by_name['UserAddRequest']
_USERUPDATEREQUEST = DESCRIPTOR.message_types_by_name['UserUpdateRequest']
_USERUPDATE = DESCRIPTOR.message_types_by_name['UserUpdate']
_USERUPDATERESPONSE = DESCRIPTOR.message_types_by_name['UserUpdateResponse']
_USERUPDATERESULT = DESCRIPTOR.message_types_by_name['UserUpdateResult']
_COMPLIANCERECORDOWNERSREQUEST = DESCRIPTOR.message_types_by_name['ComplianceRecordOwnersRequest']
_COMPLIANCERECORDOWNERSRESPONSE = DESCRIPTOR.message_types_by_name['ComplianceRecordOwnersResponse']
_RECORDOWNER = DESCRIPTOR.message_types_by_name['RecordOwner']
_PRELIMINARYCOMPLIANCEDATAREQUEST = DESCRIPTOR.message_types_by_name['PreliminaryComplianceDataRequest']
_PRELIMINARYCOMPLIANCEDATARESPONSE = DESCRIPTOR.message_types_by_name['PreliminaryComplianceDataResponse']
_AUDITUSERRECORD = DESCRIPTOR.message_types_by_name['AuditUserRecord']
_AUDITUSERDATA = DESCRIPTOR.message_types_by_name['AuditUserData']
_COMPLIANCEREPORTFILTERS = DESCRIPTOR.message_types_by_name['ComplianceReportFilters']
_COMPLIANCEREPORTREQUEST = DESCRIPTOR.message_types_by_name['ComplianceReportRequest']
_COMPLIANCEREPORTRUN = DESCRIPTOR.message_types_by_name['ComplianceReportRun']
_COMPLIANCEREPORTCRITERIAANDFILTER = DESCRIPTOR.message_types_by_name['ComplianceReportCriteriaAndFilter']
_COMPLIANCEREPORTCRITERIA = DESCRIPTOR.message_types_by_name['ComplianceReportCriteria']
_COMPLIANCEREPORTFILTER = DESCRIPTOR.message_types_by_name['ComplianceReportFilter']
_COMPLIANCEREPORTRESPONSE = DESCRIPTOR.message_types_by_name['ComplianceReportResponse']
_AUDITRECORD = DESCRIPTOR.message_types_by_name['AuditRecord']
_AUDITROLE = DESCRIPTOR.message_types_by_name['AuditRole']
_ROLENODEMANAGEMENT = DESCRIPTOR.message_types_by_name['RoleNodeManagement']
_USERPROFILE = DESCRIPTOR.message_types_by_name['UserProfile']
_RECORDPERMISSION = DESCRIPTOR.message_types_by_name['RecordPermission']
_USERRECORD = DESCRIPTOR.message_types_by_name['UserRecord']
_AUDITTEAM = DESCRIPTOR.message_types_by_name['AuditTeam']
_AUDITTEAMUSER = DESCRIPTOR.message_types_by_name['AuditTeamUser']
_SHAREDFOLDERRECORD = DESCRIPTOR.message_types_by_name['SharedFolderRecord']
_SHAREADMINRECORD = DESCRIPTOR.message_types_by_name['ShareAdminRecord']
_SHAREDFOLDERUSER = DESCRIPTOR.message_types_by_name['SharedFolderUser']
_SHAREDFOLDERTEAM = DESCRIPTOR.message_types_by_name['SharedFolderTeam']
_GETCOMPLIANCEREPORTREQUEST = DESCRIPTOR.message_types_by_name['GetComplianceReportRequest']
_GETCOMPLIANCEREPORTRESPONSE = DESCRIPTOR.message_types_by_name['GetComplianceReportResponse']
_COMPLIANCEREPORTCRITERIAREQUEST = DESCRIPTOR.message_types_by_name['ComplianceReportCriteriaRequest']
_SAVECOMPLIANCEREPORTCRITERIARESPONSE = DESCRIPTOR.message_types_by_name['SaveComplianceReportCriteriaResponse']
_LINKEDRECORD = DESCRIPTOR.message_types_by_name['LinkedRecord']
_GETSHARINGADMINSREQUEST = DESCRIPTOR.message_types_by_name['GetSharingAdminsRequest']
_USERPROFILEEXT = DESCRIPTOR.message_types_by_name['UserProfileExt']
_GETSHARINGADMINSRESPONSE = DESCRIPTOR.message_types_by_name['GetSharingAdminsResponse']
_TEAMSENTERPRISEUSERSADDREQUEST = DESCRIPTOR.message_types_by_name['TeamsEnterpriseUsersAddRequest']
_TEAMSENTERPRISEUSERSADDTEAMREQUEST = DESCRIPTOR.message_types_by_name['TeamsEnterpriseUsersAddTeamRequest']
_TEAMSENTERPRISEUSERSADDUSERREQUEST = DESCRIPTOR.message_types_by_name['TeamsEnterpriseUsersAddUserRequest']
_TEAMSENTERPRISEUSERSADDRESPONSE = DESCRIPTOR.message_types_by_name['TeamsEnterpriseUsersAddResponse']
_TEAMSENTERPRISEUSERSADDTEAMRESPONSE = DESCRIPTOR.message_types_by_name['TeamsEnterpriseUsersAddTeamResponse']
_TEAMSENTERPRISEUSERSADDUSERRESPONSE = DESCRIPTOR.message_types_by_name['TeamsEnterpriseUsersAddUserResponse']
_DOMAINALIAS = DESCRIPTOR.message_types_by_name['DomainAlias']
_DOMAINALIASREQUEST = DESCRIPTOR.message_types_by_name['DomainAliasRequest']
_DOMAINALIASRESPONSE = DESCRIPTOR.message_types_by_name['DomainAliasResponse']
_ENTERPRISEUSERSPROVISIONREQUEST = DESCRIPTOR.message_types_by_name['EnterpriseUsersProvisionRequest']
_ENTERPRISEUSERSPROVISION = DESCRIPTOR.message_types_by_name['EnterpriseUsersProvision']
_ENTERPRISEUSERSPROVISIONRESPONSE = DESCRIPTOR.message_types_by_name['EnterpriseUsersProvisionResponse']
_ENTERPRISEUSERSPROVISIONRESULT = DESCRIPTOR.message_types_by_name['EnterpriseUsersProvisionResult']
_ENTERPRISEUSERSADDREQUEST = DESCRIPTOR.message_types_by_name['EnterpriseUsersAddRequest']
_ENTERPRISEUSERSADD = DESCRIPTOR.message_types_by_name['EnterpriseUsersAdd']
_ENTERPRISEUSERSADDRESPONSE = DESCRIPTOR.message_types_by_name['EnterpriseUsersAddResponse']
_ENTERPRISEUSERSADDRESULT = DESCRIPTOR.message_types_by_name['EnterpriseUsersAddResult']
_UPDATEMSPPERMITSREQUEST = DESCRIPTOR.message_types_by_name['UpdateMSPPermitsRequest']
EnterpriseKeyPairRequest = _reflection.GeneratedProtocolMessageType('EnterpriseKeyPairRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENTERPRISEKEYPAIRREQUEST,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.EnterpriseKeyPairRequest)
  })
_sym_db.RegisterMessage(EnterpriseKeyPairRequest)

GetTeamMemberRequest = _reflection.GeneratedProtocolMessageType('GetTeamMemberRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTEAMMEMBERREQUEST,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.GetTeamMemberRequest)
  })
_sym_db.RegisterMessage(GetTeamMemberRequest)

EnterpriseUser = _reflection.GeneratedProtocolMessageType('EnterpriseUser', (_message.Message,), {
  'DESCRIPTOR' : _ENTERPRISEUSER,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.EnterpriseUser)
  })
_sym_db.RegisterMessage(EnterpriseUser)

GetTeamMemberResponse = _reflection.GeneratedProtocolMessageType('GetTeamMemberResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTEAMMEMBERRESPONSE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.GetTeamMemberResponse)
  })
_sym_db.RegisterMessage(GetTeamMemberResponse)

EnterpriseUserIds = _reflection.GeneratedProtocolMessageType('EnterpriseUserIds', (_message.Message,), {
  'DESCRIPTOR' : _ENTERPRISEUSERIDS,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.EnterpriseUserIds)
  })
_sym_db.RegisterMessage(EnterpriseUserIds)

EnterprisePersonalAccount = _reflection.GeneratedProtocolMessageType('EnterprisePersonalAccount', (_message.Message,), {
  'DESCRIPTOR' : _ENTERPRISEPERSONALACCOUNT,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.EnterprisePersonalAccount)
  })
_sym_db.RegisterMessage(EnterprisePersonalAccount)

EncryptedTeamKeyRequest = _reflection.GeneratedProtocolMessageType('EncryptedTeamKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENCRYPTEDTEAMKEYREQUEST,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.EncryptedTeamKeyRequest)
  })
_sym_db.RegisterMessage(EncryptedTeamKeyRequest)

ReEncryptedData = _reflection.GeneratedProtocolMessageType('ReEncryptedData', (_message.Message,), {
  'DESCRIPTOR' : _REENCRYPTEDDATA,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.ReEncryptedData)
  })
_sym_db.RegisterMessage(ReEncryptedData)

ReEncryptedRoleKey = _reflection.GeneratedProtocolMessageType('ReEncryptedRoleKey', (_message.Message,), {
  'DESCRIPTOR' : _REENCRYPTEDROLEKEY,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.ReEncryptedRoleKey)
  })
_sym_db.RegisterMessage(ReEncryptedRoleKey)

NodeToManagedCompanyRequest = _reflection.GeneratedProtocolMessageType('NodeToManagedCompanyRequest', (_message.Message,), {
  'DESCRIPTOR' : _NODETOMANAGEDCOMPANYREQUEST,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.NodeToManagedCompanyRequest)
  })
_sym_db.RegisterMessage(NodeToManagedCompanyRequest)

RoleTeam = _reflection.GeneratedProtocolMessageType('RoleTeam', (_message.Message,), {
  'DESCRIPTOR' : _ROLETEAM,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.RoleTeam)
  })
_sym_db.RegisterMessage(RoleTeam)

RoleTeams = _reflection.GeneratedProtocolMessageType('RoleTeams', (_message.Message,), {
  'DESCRIPTOR' : _ROLETEAMS,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.RoleTeams)
  })
_sym_db.RegisterMessage(RoleTeams)

EnterpriseRegistration = _reflection.GeneratedProtocolMessageType('EnterpriseRegistration', (_message.Message,), {
  'DESCRIPTOR' : _ENTERPRISEREGISTRATION,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.EnterpriseRegistration)
  })
_sym_db.RegisterMessage(EnterpriseRegistration)

DomainPasswordRulesRequest = _reflection.GeneratedProtocolMessageType('DomainPasswordRulesRequest', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINPASSWORDRULESREQUEST,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.DomainPasswordRulesRequest)
  })
_sym_db.RegisterMessage(DomainPasswordRulesRequest)

DomainPasswordRulesFields = _reflection.GeneratedProtocolMessageType('DomainPasswordRulesFields', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINPASSWORDRULESFIELDS,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.DomainPasswordRulesFields)
  })
_sym_db.RegisterMessage(DomainPasswordRulesFields)

LoginToMcRequest = _reflection.GeneratedProtocolMessageType('LoginToMcRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOGINTOMCREQUEST,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.LoginToMcRequest)
  })
_sym_db.RegisterMessage(LoginToMcRequest)

LoginToMcResponse = _reflection.GeneratedProtocolMessageType('LoginToMcResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOGINTOMCRESPONSE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.LoginToMcResponse)
  })
_sym_db.RegisterMessage(LoginToMcResponse)

DomainPasswordRulesResponse = _reflection.GeneratedProtocolMessageType('DomainPasswordRulesResponse', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINPASSWORDRULESRESPONSE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.DomainPasswordRulesResponse)
  })
_sym_db.RegisterMessage(DomainPasswordRulesResponse)

ApproveUserDeviceRequest = _reflection.GeneratedProtocolMessageType('ApproveUserDeviceRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPROVEUSERDEVICEREQUEST,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.ApproveUserDeviceRequest)
  })
_sym_db.RegisterMessage(ApproveUserDeviceRequest)

ApproveUserDeviceResponse = _reflection.GeneratedProtocolMessageType('ApproveUserDeviceResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPROVEUSERDEVICERESPONSE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.ApproveUserDeviceResponse)
  })
_sym_db.RegisterMessage(ApproveUserDeviceResponse)

ApproveUserDevicesRequest = _reflection.GeneratedProtocolMessageType('ApproveUserDevicesRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPROVEUSERDEVICESREQUEST,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.ApproveUserDevicesRequest)
  })
_sym_db.RegisterMessage(ApproveUserDevicesRequest)

ApproveUserDevicesResponse = _reflection.GeneratedProtocolMessageType('ApproveUserDevicesResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPROVEUSERDEVICESRESPONSE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.ApproveUserDevicesResponse)
  })
_sym_db.RegisterMessage(ApproveUserDevicesResponse)

EnterpriseUserDataKey = _reflection.GeneratedProtocolMessageType('EnterpriseUserDataKey', (_message.Message,), {
  'DESCRIPTOR' : _ENTERPRISEUSERDATAKEY,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.EnterpriseUserDataKey)
  })
_sym_db.RegisterMessage(EnterpriseUserDataKey)

EnterpriseUserDataKeys = _reflection.GeneratedProtocolMessageType('EnterpriseUserDataKeys', (_message.Message,), {
  'DESCRIPTOR' : _ENTERPRISEUSERDATAKEYS,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.EnterpriseUserDataKeys)
  })
_sym_db.RegisterMessage(EnterpriseUserDataKeys)

EnterpriseDataRequest = _reflection.GeneratedProtocolMessageType('EnterpriseDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENTERPRISEDATAREQUEST,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.EnterpriseDataRequest)
  })
_sym_db.RegisterMessage(EnterpriseDataRequest)

SpecialProvisioning = _reflection.GeneratedProtocolMessageType('SpecialProvisioning', (_message.Message,), {
  'DESCRIPTOR' : _SPECIALPROVISIONING,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.SpecialProvisioning)
  })
_sym_db.RegisterMessage(SpecialProvisioning)

GeneralDataEntity = _reflection.GeneratedProtocolMessageType('GeneralDataEntity', (_message.Message,), {
  'DESCRIPTOR' : _GENERALDATAENTITY,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.GeneralDataEntity)
  })
_sym_db.RegisterMessage(GeneralDataEntity)

Node = _reflection.GeneratedProtocolMessageType('Node', (_message.Message,), {
  'DESCRIPTOR' : _NODE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.Node)
  })
_sym_db.RegisterMessage(Node)

Role = _reflection.GeneratedProtocolMessageType('Role', (_message.Message,), {
  'DESCRIPTOR' : _ROLE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.Role)
  })
_sym_db.RegisterMessage(Role)

User = _reflection.GeneratedProtocolMessageType('User', (_message.Message,), {
  'DESCRIPTOR' : _USER,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.User)
  })
_sym_db.RegisterMessage(User)

UserAlias = _reflection.GeneratedProtocolMessageType('UserAlias', (_message.Message,), {
  'DESCRIPTOR' : _USERALIAS,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.UserAlias)
  })
_sym_db.RegisterMessage(UserAlias)

ComplianceReportMetaData = _reflection.GeneratedProtocolMessageType('ComplianceReportMetaData', (_message.Message,), {
  'DESCRIPTOR' : _COMPLIANCEREPORTMETADATA,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.ComplianceReportMetaData)
  })
_sym_db.RegisterMessage(ComplianceReportMetaData)

ManagedNode = _reflection.GeneratedProtocolMessageType('ManagedNode', (_message.Message,), {
  'DESCRIPTOR' : _MANAGEDNODE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.ManagedNode)
  })
_sym_db.RegisterMessage(ManagedNode)

UserManagedNode = _reflection.GeneratedProtocolMessageType('UserManagedNode', (_message.Message,), {
  'DESCRIPTOR' : _USERMANAGEDNODE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.UserManagedNode)
  })
_sym_db.RegisterMessage(UserManagedNode)

UserPrivilege = _reflection.GeneratedProtocolMessageType('UserPrivilege', (_message.Message,), {
  'DESCRIPTOR' : _USERPRIVILEGE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.UserPrivilege)
  })
_sym_db.RegisterMessage(UserPrivilege)

RoleUser = _reflection.GeneratedProtocolMessageType('RoleUser', (_message.Message,), {
  'DESCRIPTOR' : _ROLEUSER,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.RoleUser)
  })
_sym_db.RegisterMessage(RoleUser)

RolePrivilege = _reflection.GeneratedProtocolMessageType('RolePrivilege', (_message.Message,), {
  'DESCRIPTOR' : _ROLEPRIVILEGE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.RolePrivilege)
  })
_sym_db.RegisterMessage(RolePrivilege)

RoleEnforcement = _reflection.GeneratedProtocolMessageType('RoleEnforcement', (_message.Message,), {
  'DESCRIPTOR' : _ROLEENFORCEMENT,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.RoleEnforcement)
  })
_sym_db.RegisterMessage(RoleEnforcement)

Team = _reflection.GeneratedProtocolMessageType('Team', (_message.Message,), {
  'DESCRIPTOR' : _TEAM,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.Team)
  })
_sym_db.RegisterMessage(Team)

TeamUser = _reflection.GeneratedProtocolMessageType('TeamUser', (_message.Message,), {
  'DESCRIPTOR' : _TEAMUSER,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.TeamUser)
  })
_sym_db.RegisterMessage(TeamUser)

GetDistributorInfoResponse = _reflection.GeneratedProtocolMessageType('GetDistributorInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDISTRIBUTORINFORESPONSE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.GetDistributorInfoResponse)
  })
_sym_db.RegisterMessage(GetDistributorInfoResponse)

Distributor = _reflection.GeneratedProtocolMessageType('Distributor', (_message.Message,), {
  'DESCRIPTOR' : _DISTRIBUTOR,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.Distributor)
  })
_sym_db.RegisterMessage(Distributor)

MspInfo = _reflection.GeneratedProtocolMessageType('MspInfo', (_message.Message,), {
  'DESCRIPTOR' : _MSPINFO,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.MspInfo)
  })
_sym_db.RegisterMessage(MspInfo)

ManagedCompany = _reflection.GeneratedProtocolMessageType('ManagedCompany', (_message.Message,), {
  'DESCRIPTOR' : _MANAGEDCOMPANY,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.ManagedCompany)
  })
_sym_db.RegisterMessage(ManagedCompany)

MSPPool = _reflection.GeneratedProtocolMessageType('MSPPool', (_message.Message,), {
  'DESCRIPTOR' : _MSPPOOL,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.MSPPool)
  })
_sym_db.RegisterMessage(MSPPool)

MSPContact = _reflection.GeneratedProtocolMessageType('MSPContact', (_message.Message,), {
  'DESCRIPTOR' : _MSPCONTACT,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.MSPContact)
  })
_sym_db.RegisterMessage(MSPContact)

LicenseAddOn = _reflection.GeneratedProtocolMessageType('LicenseAddOn', (_message.Message,), {
  'DESCRIPTOR' : _LICENSEADDON,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.LicenseAddOn)
  })
_sym_db.RegisterMessage(LicenseAddOn)

MCDefault = _reflection.GeneratedProtocolMessageType('MCDefault', (_message.Message,), {
  'DESCRIPTOR' : _MCDEFAULT,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.MCDefault)
  })
_sym_db.RegisterMessage(MCDefault)

MSPPermits = _reflection.GeneratedProtocolMessageType('MSPPermits', (_message.Message,), {
  'DESCRIPTOR' : _MSPPERMITS,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.MSPPermits)
  })
_sym_db.RegisterMessage(MSPPermits)

License = _reflection.GeneratedProtocolMessageType('License', (_message.Message,), {
  'DESCRIPTOR' : _LICENSE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.License)
  })
_sym_db.RegisterMessage(License)

Bridge = _reflection.GeneratedProtocolMessageType('Bridge', (_message.Message,), {
  'DESCRIPTOR' : _BRIDGE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.Bridge)
  })
_sym_db.RegisterMessage(Bridge)

Scim = _reflection.GeneratedProtocolMessageType('Scim', (_message.Message,), {
  'DESCRIPTOR' : _SCIM,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.Scim)
  })
_sym_db.RegisterMessage(Scim)

EmailProvision = _reflection.GeneratedProtocolMessageType('EmailProvision', (_message.Message,), {
  'DESCRIPTOR' : _EMAILPROVISION,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.EmailProvision)
  })
_sym_db.RegisterMessage(EmailProvision)

QueuedTeam = _reflection.GeneratedProtocolMessageType('QueuedTeam', (_message.Message,), {
  'DESCRIPTOR' : _QUEUEDTEAM,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.QueuedTeam)
  })
_sym_db.RegisterMessage(QueuedTeam)

QueuedTeamUser = _reflection.GeneratedProtocolMessageType('QueuedTeamUser', (_message.Message,), {
  'DESCRIPTOR' : _QUEUEDTEAMUSER,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.QueuedTeamUser)
  })
_sym_db.RegisterMessage(QueuedTeamUser)

SsoService = _reflection.GeneratedProtocolMessageType('SsoService', (_message.Message,), {
  'DESCRIPTOR' : _SSOSERVICE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.SsoService)
  })
_sym_db.RegisterMessage(SsoService)

ReportFilterUser = _reflection.GeneratedProtocolMessageType('ReportFilterUser', (_message.Message,), {
  'DESCRIPTOR' : _REPORTFILTERUSER,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.ReportFilterUser)
  })
_sym_db.RegisterMessage(ReportFilterUser)

DeviceRequestForAdminApproval = _reflection.GeneratedProtocolMessageType('DeviceRequestForAdminApproval', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEREQUESTFORADMINAPPROVAL,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.DeviceRequestForAdminApproval)
  })
_sym_db.RegisterMessage(DeviceRequestForAdminApproval)

EnterpriseData = _reflection.GeneratedProtocolMessageType('EnterpriseData', (_message.Message,), {
  'DESCRIPTOR' : _ENTERPRISEDATA,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.EnterpriseData)
  })
_sym_db.RegisterMessage(EnterpriseData)

EnterpriseDataResponse = _reflection.GeneratedProtocolMessageType('EnterpriseDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _ENTERPRISEDATARESPONSE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.EnterpriseDataResponse)
  })
_sym_db.RegisterMessage(EnterpriseDataResponse)

BackupRequest = _reflection.GeneratedProtocolMessageType('BackupRequest', (_message.Message,), {
  'DESCRIPTOR' : _BACKUPREQUEST,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.BackupRequest)
  })
_sym_db.RegisterMessage(BackupRequest)

BackupRecord = _reflection.GeneratedProtocolMessageType('BackupRecord', (_message.Message,), {
  'DESCRIPTOR' : _BACKUPRECORD,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.BackupRecord)
  })
_sym_db.RegisterMessage(BackupRecord)

BackupKey = _reflection.GeneratedProtocolMessageType('BackupKey', (_message.Message,), {
  'DESCRIPTOR' : _BACKUPKEY,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.BackupKey)
  })
_sym_db.RegisterMessage(BackupKey)

BackupUser = _reflection.GeneratedProtocolMessageType('BackupUser', (_message.Message,), {
  'DESCRIPTOR' : _BACKUPUSER,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.BackupUser)
  })
_sym_db.RegisterMessage(BackupUser)

BackupResponse = _reflection.GeneratedProtocolMessageType('BackupResponse', (_message.Message,), {
  'DESCRIPTOR' : _BACKUPRESPONSE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.BackupResponse)
  })
_sym_db.RegisterMessage(BackupResponse)

BackupFile = _reflection.GeneratedProtocolMessageType('BackupFile', (_message.Message,), {
  'DESCRIPTOR' : _BACKUPFILE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.BackupFile)
  })
_sym_db.RegisterMessage(BackupFile)

BackupsResponse = _reflection.GeneratedProtocolMessageType('BackupsResponse', (_message.Message,), {
  'DESCRIPTOR' : _BACKUPSRESPONSE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.BackupsResponse)
  })
_sym_db.RegisterMessage(BackupsResponse)

GetEnterpriseDataKeysRequest = _reflection.GeneratedProtocolMessageType('GetEnterpriseDataKeysRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETENTERPRISEDATAKEYSREQUEST,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.GetEnterpriseDataKeysRequest)
  })
_sym_db.RegisterMessage(GetEnterpriseDataKeysRequest)

GetEnterpriseDataKeysResponse = _reflection.GeneratedProtocolMessageType('GetEnterpriseDataKeysResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETENTERPRISEDATAKEYSRESPONSE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.GetEnterpriseDataKeysResponse)
  })
_sym_db.RegisterMessage(GetEnterpriseDataKeysResponse)

RoleKey = _reflection.GeneratedProtocolMessageType('RoleKey', (_message.Message,), {
  'DESCRIPTOR' : _ROLEKEY,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.RoleKey)
  })
_sym_db.RegisterMessage(RoleKey)

MspKey = _reflection.GeneratedProtocolMessageType('MspKey', (_message.Message,), {
  'DESCRIPTOR' : _MSPKEY,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.MspKey)
  })
_sym_db.RegisterMessage(MspKey)

EnterpriseKeys = _reflection.GeneratedProtocolMessageType('EnterpriseKeys', (_message.Message,), {
  'DESCRIPTOR' : _ENTERPRISEKEYS,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.EnterpriseKeys)
  })
_sym_db.RegisterMessage(EnterpriseKeys)

TreeKey = _reflection.GeneratedProtocolMessageType('TreeKey', (_message.Message,), {
  'DESCRIPTOR' : _TREEKEY,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.TreeKey)
  })
_sym_db.RegisterMessage(TreeKey)

SharedRecordResponse = _reflection.GeneratedProtocolMessageType('SharedRecordResponse', (_message.Message,), {
  'DESCRIPTOR' : _SHAREDRECORDRESPONSE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.SharedRecordResponse)
  })
_sym_db.RegisterMessage(SharedRecordResponse)

SharedRecordEvent = _reflection.GeneratedProtocolMessageType('SharedRecordEvent', (_message.Message,), {
  'DESCRIPTOR' : _SHAREDRECORDEVENT,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.SharedRecordEvent)
  })
_sym_db.RegisterMessage(SharedRecordEvent)

SetRestrictVisibilityRequest = _reflection.GeneratedProtocolMessageType('SetRestrictVisibilityRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETRESTRICTVISIBILITYREQUEST,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.SetRestrictVisibilityRequest)
  })
_sym_db.RegisterMessage(SetRestrictVisibilityRequest)

UserAddRequest = _reflection.GeneratedProtocolMessageType('UserAddRequest', (_message.Message,), {
  'DESCRIPTOR' : _USERADDREQUEST,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.UserAddRequest)
  })
_sym_db.RegisterMessage(UserAddRequest)

UserUpdateRequest = _reflection.GeneratedProtocolMessageType('UserUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _USERUPDATEREQUEST,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.UserUpdateRequest)
  })
_sym_db.RegisterMessage(UserUpdateRequest)

UserUpdate = _reflection.GeneratedProtocolMessageType('UserUpdate', (_message.Message,), {
  'DESCRIPTOR' : _USERUPDATE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.UserUpdate)
  })
_sym_db.RegisterMessage(UserUpdate)

UserUpdateResponse = _reflection.GeneratedProtocolMessageType('UserUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _USERUPDATERESPONSE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.UserUpdateResponse)
  })
_sym_db.RegisterMessage(UserUpdateResponse)

UserUpdateResult = _reflection.GeneratedProtocolMessageType('UserUpdateResult', (_message.Message,), {
  'DESCRIPTOR' : _USERUPDATERESULT,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.UserUpdateResult)
  })
_sym_db.RegisterMessage(UserUpdateResult)

ComplianceRecordOwnersRequest = _reflection.GeneratedProtocolMessageType('ComplianceRecordOwnersRequest', (_message.Message,), {
  'DESCRIPTOR' : _COMPLIANCERECORDOWNERSREQUEST,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.ComplianceRecordOwnersRequest)
  })
_sym_db.RegisterMessage(ComplianceRecordOwnersRequest)

ComplianceRecordOwnersResponse = _reflection.GeneratedProtocolMessageType('ComplianceRecordOwnersResponse', (_message.Message,), {
  'DESCRIPTOR' : _COMPLIANCERECORDOWNERSRESPONSE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.ComplianceRecordOwnersResponse)
  })
_sym_db.RegisterMessage(ComplianceRecordOwnersResponse)

RecordOwner = _reflection.GeneratedProtocolMessageType('RecordOwner', (_message.Message,), {
  'DESCRIPTOR' : _RECORDOWNER,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.RecordOwner)
  })
_sym_db.RegisterMessage(RecordOwner)

PreliminaryComplianceDataRequest = _reflection.GeneratedProtocolMessageType('PreliminaryComplianceDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _PRELIMINARYCOMPLIANCEDATAREQUEST,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.PreliminaryComplianceDataRequest)
  })
_sym_db.RegisterMessage(PreliminaryComplianceDataRequest)

PreliminaryComplianceDataResponse = _reflection.GeneratedProtocolMessageType('PreliminaryComplianceDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _PRELIMINARYCOMPLIANCEDATARESPONSE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.PreliminaryComplianceDataResponse)
  })
_sym_db.RegisterMessage(PreliminaryComplianceDataResponse)

AuditUserRecord = _reflection.GeneratedProtocolMessageType('AuditUserRecord', (_message.Message,), {
  'DESCRIPTOR' : _AUDITUSERRECORD,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.AuditUserRecord)
  })
_sym_db.RegisterMessage(AuditUserRecord)

AuditUserData = _reflection.GeneratedProtocolMessageType('AuditUserData', (_message.Message,), {
  'DESCRIPTOR' : _AUDITUSERDATA,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.AuditUserData)
  })
_sym_db.RegisterMessage(AuditUserData)

ComplianceReportFilters = _reflection.GeneratedProtocolMessageType('ComplianceReportFilters', (_message.Message,), {
  'DESCRIPTOR' : _COMPLIANCEREPORTFILTERS,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.ComplianceReportFilters)
  })
_sym_db.RegisterMessage(ComplianceReportFilters)

ComplianceReportRequest = _reflection.GeneratedProtocolMessageType('ComplianceReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _COMPLIANCEREPORTREQUEST,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.ComplianceReportRequest)
  })
_sym_db.RegisterMessage(ComplianceReportRequest)

ComplianceReportRun = _reflection.GeneratedProtocolMessageType('ComplianceReportRun', (_message.Message,), {
  'DESCRIPTOR' : _COMPLIANCEREPORTRUN,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.ComplianceReportRun)
  })
_sym_db.RegisterMessage(ComplianceReportRun)

ComplianceReportCriteriaAndFilter = _reflection.GeneratedProtocolMessageType('ComplianceReportCriteriaAndFilter', (_message.Message,), {
  'DESCRIPTOR' : _COMPLIANCEREPORTCRITERIAANDFILTER,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.ComplianceReportCriteriaAndFilter)
  })
_sym_db.RegisterMessage(ComplianceReportCriteriaAndFilter)

ComplianceReportCriteria = _reflection.GeneratedProtocolMessageType('ComplianceReportCriteria', (_message.Message,), {
  'DESCRIPTOR' : _COMPLIANCEREPORTCRITERIA,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.ComplianceReportCriteria)
  })
_sym_db.RegisterMessage(ComplianceReportCriteria)

ComplianceReportFilter = _reflection.GeneratedProtocolMessageType('ComplianceReportFilter', (_message.Message,), {
  'DESCRIPTOR' : _COMPLIANCEREPORTFILTER,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.ComplianceReportFilter)
  })
_sym_db.RegisterMessage(ComplianceReportFilter)

ComplianceReportResponse = _reflection.GeneratedProtocolMessageType('ComplianceReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _COMPLIANCEREPORTRESPONSE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.ComplianceReportResponse)
  })
_sym_db.RegisterMessage(ComplianceReportResponse)

AuditRecord = _reflection.GeneratedProtocolMessageType('AuditRecord', (_message.Message,), {
  'DESCRIPTOR' : _AUDITRECORD,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.AuditRecord)
  })
_sym_db.RegisterMessage(AuditRecord)

AuditRole = _reflection.GeneratedProtocolMessageType('AuditRole', (_message.Message,), {
  'DESCRIPTOR' : _AUDITROLE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.AuditRole)
  })
_sym_db.RegisterMessage(AuditRole)

RoleNodeManagement = _reflection.GeneratedProtocolMessageType('RoleNodeManagement', (_message.Message,), {
  'DESCRIPTOR' : _ROLENODEMANAGEMENT,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.RoleNodeManagement)
  })
_sym_db.RegisterMessage(RoleNodeManagement)

UserProfile = _reflection.GeneratedProtocolMessageType('UserProfile', (_message.Message,), {
  'DESCRIPTOR' : _USERPROFILE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.UserProfile)
  })
_sym_db.RegisterMessage(UserProfile)

RecordPermission = _reflection.GeneratedProtocolMessageType('RecordPermission', (_message.Message,), {
  'DESCRIPTOR' : _RECORDPERMISSION,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.RecordPermission)
  })
_sym_db.RegisterMessage(RecordPermission)

UserRecord = _reflection.GeneratedProtocolMessageType('UserRecord', (_message.Message,), {
  'DESCRIPTOR' : _USERRECORD,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.UserRecord)
  })
_sym_db.RegisterMessage(UserRecord)

AuditTeam = _reflection.GeneratedProtocolMessageType('AuditTeam', (_message.Message,), {
  'DESCRIPTOR' : _AUDITTEAM,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.AuditTeam)
  })
_sym_db.RegisterMessage(AuditTeam)

AuditTeamUser = _reflection.GeneratedProtocolMessageType('AuditTeamUser', (_message.Message,), {
  'DESCRIPTOR' : _AUDITTEAMUSER,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.AuditTeamUser)
  })
_sym_db.RegisterMessage(AuditTeamUser)

SharedFolderRecord = _reflection.GeneratedProtocolMessageType('SharedFolderRecord', (_message.Message,), {
  'DESCRIPTOR' : _SHAREDFOLDERRECORD,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.SharedFolderRecord)
  })
_sym_db.RegisterMessage(SharedFolderRecord)

ShareAdminRecord = _reflection.GeneratedProtocolMessageType('ShareAdminRecord', (_message.Message,), {
  'DESCRIPTOR' : _SHAREADMINRECORD,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.ShareAdminRecord)
  })
_sym_db.RegisterMessage(ShareAdminRecord)

SharedFolderUser = _reflection.GeneratedProtocolMessageType('SharedFolderUser', (_message.Message,), {
  'DESCRIPTOR' : _SHAREDFOLDERUSER,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.SharedFolderUser)
  })
_sym_db.RegisterMessage(SharedFolderUser)

SharedFolderTeam = _reflection.GeneratedProtocolMessageType('SharedFolderTeam', (_message.Message,), {
  'DESCRIPTOR' : _SHAREDFOLDERTEAM,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.SharedFolderTeam)
  })
_sym_db.RegisterMessage(SharedFolderTeam)

GetComplianceReportRequest = _reflection.GeneratedProtocolMessageType('GetComplianceReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCOMPLIANCEREPORTREQUEST,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.GetComplianceReportRequest)
  })
_sym_db.RegisterMessage(GetComplianceReportRequest)

GetComplianceReportResponse = _reflection.GeneratedProtocolMessageType('GetComplianceReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCOMPLIANCEREPORTRESPONSE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.GetComplianceReportResponse)
  })
_sym_db.RegisterMessage(GetComplianceReportResponse)

ComplianceReportCriteriaRequest = _reflection.GeneratedProtocolMessageType('ComplianceReportCriteriaRequest', (_message.Message,), {
  'DESCRIPTOR' : _COMPLIANCEREPORTCRITERIAREQUEST,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.ComplianceReportCriteriaRequest)
  })
_sym_db.RegisterMessage(ComplianceReportCriteriaRequest)

SaveComplianceReportCriteriaResponse = _reflection.GeneratedProtocolMessageType('SaveComplianceReportCriteriaResponse', (_message.Message,), {
  'DESCRIPTOR' : _SAVECOMPLIANCEREPORTCRITERIARESPONSE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.SaveComplianceReportCriteriaResponse)
  })
_sym_db.RegisterMessage(SaveComplianceReportCriteriaResponse)

LinkedRecord = _reflection.GeneratedProtocolMessageType('LinkedRecord', (_message.Message,), {
  'DESCRIPTOR' : _LINKEDRECORD,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.LinkedRecord)
  })
_sym_db.RegisterMessage(LinkedRecord)

GetSharingAdminsRequest = _reflection.GeneratedProtocolMessageType('GetSharingAdminsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSHARINGADMINSREQUEST,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.GetSharingAdminsRequest)
  })
_sym_db.RegisterMessage(GetSharingAdminsRequest)

UserProfileExt = _reflection.GeneratedProtocolMessageType('UserProfileExt', (_message.Message,), {
  'DESCRIPTOR' : _USERPROFILEEXT,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.UserProfileExt)
  })
_sym_db.RegisterMessage(UserProfileExt)

GetSharingAdminsResponse = _reflection.GeneratedProtocolMessageType('GetSharingAdminsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSHARINGADMINSRESPONSE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.GetSharingAdminsResponse)
  })
_sym_db.RegisterMessage(GetSharingAdminsResponse)

TeamsEnterpriseUsersAddRequest = _reflection.GeneratedProtocolMessageType('TeamsEnterpriseUsersAddRequest', (_message.Message,), {
  'DESCRIPTOR' : _TEAMSENTERPRISEUSERSADDREQUEST,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.TeamsEnterpriseUsersAddRequest)
  })
_sym_db.RegisterMessage(TeamsEnterpriseUsersAddRequest)

TeamsEnterpriseUsersAddTeamRequest = _reflection.GeneratedProtocolMessageType('TeamsEnterpriseUsersAddTeamRequest', (_message.Message,), {
  'DESCRIPTOR' : _TEAMSENTERPRISEUSERSADDTEAMREQUEST,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.TeamsEnterpriseUsersAddTeamRequest)
  })
_sym_db.RegisterMessage(TeamsEnterpriseUsersAddTeamRequest)

TeamsEnterpriseUsersAddUserRequest = _reflection.GeneratedProtocolMessageType('TeamsEnterpriseUsersAddUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _TEAMSENTERPRISEUSERSADDUSERREQUEST,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.TeamsEnterpriseUsersAddUserRequest)
  })
_sym_db.RegisterMessage(TeamsEnterpriseUsersAddUserRequest)

TeamsEnterpriseUsersAddResponse = _reflection.GeneratedProtocolMessageType('TeamsEnterpriseUsersAddResponse', (_message.Message,), {
  'DESCRIPTOR' : _TEAMSENTERPRISEUSERSADDRESPONSE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.TeamsEnterpriseUsersAddResponse)
  })
_sym_db.RegisterMessage(TeamsEnterpriseUsersAddResponse)

TeamsEnterpriseUsersAddTeamResponse = _reflection.GeneratedProtocolMessageType('TeamsEnterpriseUsersAddTeamResponse', (_message.Message,), {
  'DESCRIPTOR' : _TEAMSENTERPRISEUSERSADDTEAMRESPONSE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.TeamsEnterpriseUsersAddTeamResponse)
  })
_sym_db.RegisterMessage(TeamsEnterpriseUsersAddTeamResponse)

TeamsEnterpriseUsersAddUserResponse = _reflection.GeneratedProtocolMessageType('TeamsEnterpriseUsersAddUserResponse', (_message.Message,), {
  'DESCRIPTOR' : _TEAMSENTERPRISEUSERSADDUSERRESPONSE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.TeamsEnterpriseUsersAddUserResponse)
  })
_sym_db.RegisterMessage(TeamsEnterpriseUsersAddUserResponse)

DomainAlias = _reflection.GeneratedProtocolMessageType('DomainAlias', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINALIAS,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.DomainAlias)
  })
_sym_db.RegisterMessage(DomainAlias)

DomainAliasRequest = _reflection.GeneratedProtocolMessageType('DomainAliasRequest', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINALIASREQUEST,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.DomainAliasRequest)
  })
_sym_db.RegisterMessage(DomainAliasRequest)

DomainAliasResponse = _reflection.GeneratedProtocolMessageType('DomainAliasResponse', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINALIASRESPONSE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.DomainAliasResponse)
  })
_sym_db.RegisterMessage(DomainAliasResponse)

EnterpriseUsersProvisionRequest = _reflection.GeneratedProtocolMessageType('EnterpriseUsersProvisionRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENTERPRISEUSERSPROVISIONREQUEST,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.EnterpriseUsersProvisionRequest)
  })
_sym_db.RegisterMessage(EnterpriseUsersProvisionRequest)

EnterpriseUsersProvision = _reflection.GeneratedProtocolMessageType('EnterpriseUsersProvision', (_message.Message,), {
  'DESCRIPTOR' : _ENTERPRISEUSERSPROVISION,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.EnterpriseUsersProvision)
  })
_sym_db.RegisterMessage(EnterpriseUsersProvision)

EnterpriseUsersProvisionResponse = _reflection.GeneratedProtocolMessageType('EnterpriseUsersProvisionResponse', (_message.Message,), {
  'DESCRIPTOR' : _ENTERPRISEUSERSPROVISIONRESPONSE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.EnterpriseUsersProvisionResponse)
  })
_sym_db.RegisterMessage(EnterpriseUsersProvisionResponse)

EnterpriseUsersProvisionResult = _reflection.GeneratedProtocolMessageType('EnterpriseUsersProvisionResult', (_message.Message,), {
  'DESCRIPTOR' : _ENTERPRISEUSERSPROVISIONRESULT,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.EnterpriseUsersProvisionResult)
  })
_sym_db.RegisterMessage(EnterpriseUsersProvisionResult)

EnterpriseUsersAddRequest = _reflection.GeneratedProtocolMessageType('EnterpriseUsersAddRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENTERPRISEUSERSADDREQUEST,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.EnterpriseUsersAddRequest)
  })
_sym_db.RegisterMessage(EnterpriseUsersAddRequest)

EnterpriseUsersAdd = _reflection.GeneratedProtocolMessageType('EnterpriseUsersAdd', (_message.Message,), {
  'DESCRIPTOR' : _ENTERPRISEUSERSADD,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.EnterpriseUsersAdd)
  })
_sym_db.RegisterMessage(EnterpriseUsersAdd)

EnterpriseUsersAddResponse = _reflection.GeneratedProtocolMessageType('EnterpriseUsersAddResponse', (_message.Message,), {
  'DESCRIPTOR' : _ENTERPRISEUSERSADDRESPONSE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.EnterpriseUsersAddResponse)
  })
_sym_db.RegisterMessage(EnterpriseUsersAddResponse)

EnterpriseUsersAddResult = _reflection.GeneratedProtocolMessageType('EnterpriseUsersAddResult', (_message.Message,), {
  'DESCRIPTOR' : _ENTERPRISEUSERSADDRESULT,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.EnterpriseUsersAddResult)
  })
_sym_db.RegisterMessage(EnterpriseUsersAddResult)

UpdateMSPPermitsRequest = _reflection.GeneratedProtocolMessageType('UpdateMSPPermitsRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMSPPERMITSREQUEST,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.UpdateMSPPermitsRequest)
  })
_sym_db.RegisterMessage(UpdateMSPPermitsRequest)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030com.keepersecurity.protoB\nEnterprise'
  _NODE.fields_by_name['ssoServiceProviderId']._options = None
  _NODE.fields_by_name['ssoServiceProviderId']._serialized_options = b'\030\001'
  _NODE.fields_by_name['ssoServiceProviderIds']._options = None
  _NODE.fields_by_name['ssoServiceProviderIds']._serialized_options = b'\020\001'
  _KEYTYPE._serialized_start=16786
  _KEYTYPE._serialized_end=16813
  _ENTERPRISETYPE._serialized_start=16815
  _ENTERPRISETYPE._serialized_end=16876
  _ENTERPRISEDATAENTITY._serialized_start=16879
  _ENTERPRISEDATAENTITY._serialized_end=17360
  _CACHESTATUS._serialized_start=17362
  _CACHESTATUS._serialized_end=17396
  _BACKUPKEYTYPE._serialized_start=17399
  _BACKUPKEYTYPE._serialized_end=17546
  _BACKUPUSERDATAKEYTYPE._serialized_start=17548
  _BACKUPUSERDATAKEYTYPE._serialized_end=17606
  _ENCRYPTEDKEYTYPE._serialized_start=17609
  _ENCRYPTEDKEYTYPE._serialized_end=17774
  _ENTERPRISEFLAGTYPE._serialized_start=17777
  _ENTERPRISEFLAGTYPE._serialized_end=17926
  _USERUPDATESTATUS._serialized_start=17928
  _USERUPDATESTATUS._serialized_end=17997
  _AUDITUSERSTATUS._serialized_start=17999
  _AUDITUSERSTATUS._serialized_end=18072
  _TEAMUSERTYPE._serialized_start=18074
  _TEAMUSERTYPE._serialized_end=18125
  _APPCLIENTTYPE._serialized_start=18127
  _APPCLIENTTYPE._serialized_end=18228
  _ENTERPRISEKEYPAIRREQUEST._serialized_start=33
  _ENTERPRISEKEYPAIRREQUEST._serialized_end=165
  _GETTEAMMEMBERREQUEST._serialized_start=167
  _GETTEAMMEMBERREQUEST._serialized_end=206
  _ENTERPRISEUSER._serialized_start=208
  _ENTERPRISEUSER._serialized_end=315
  _GETTEAMMEMBERRESPONSE._serialized_start=317
  _GETTEAMMEMBERRESPONSE._serialized_end=392
  _ENTERPRISEUSERIDS._serialized_start=394
  _ENTERPRISEUSERIDS._serialized_end=439
  _ENTERPRISEPERSONALACCOUNT._serialized_start=441
  _ENTERPRISEPERSONALACCOUNT._serialized_end=507
  _ENCRYPTEDTEAMKEYREQUEST._serialized_start=509
  _ENCRYPTEDTEAMKEYREQUEST._serialized_end=592
  _REENCRYPTEDDATA._serialized_start=594
  _REENCRYPTEDDATA._serialized_end=637
  _REENCRYPTEDROLEKEY._serialized_start=639
  _REENCRYPTEDROLEKEY._serialized_end=702
  _NODETOMANAGEDCOMPANYREQUEST._serialized_start=705
  _NODETOMANAGEDCOMPANYREQUEST._serialized_end=990
  _ROLETEAM._serialized_start=992
  _ROLETEAM._serialized_end=1036
  _ROLETEAMS._serialized_start=1038
  _ROLETEAMS._serialized_end=1090
  _ENTERPRISEREGISTRATION._serialized_start=1093
  _ENTERPRISEREGISTRATION._serialized_end=1542
  _DOMAINPASSWORDRULESREQUEST._serialized_start=1544
  _DOMAINPASSWORDRULESREQUEST._serialized_end=1590
  _DOMAINPASSWORDRULESFIELDS._serialized_start=1592
  _DOMAINPASSWORDRULESFIELDS._serialized_end=1684
  _LOGINTOMCREQUEST._serialized_start=1686
  _LOGINTOMCREQUEST._serialized_end=1755
  _LOGINTOMCRESPONSE._serialized_start=1757
  _LOGINTOMCRESPONSE._serialized_end=1833
  _DOMAINPASSWORDRULESRESPONSE._serialized_start=1835
  _DOMAINPASSWORDRULESRESPONSE._serialized_end=1938
  _APPROVEUSERDEVICEREQUEST._serialized_start=1941
  _APPROVEUSERDEVICEREQUEST._serialized_end=2077
  _APPROVEUSERDEVICERESPONSE._serialized_start=2079
  _APPROVEUSERDEVICERESPONSE._serialized_end=2195
  _APPROVEUSERDEVICESREQUEST._serialized_start=2197
  _APPROVEUSERDEVICESREQUEST._serialized_end=2286
  _APPROVEUSERDEVICESRESPONSE._serialized_start=2288
  _APPROVEUSERDEVICESRESPONSE._serialized_end=2380
  _ENTERPRISEUSERDATAKEY._serialized_start=2382
  _ENTERPRISEUSERDATAKEY._serialized_end=2480
  _ENTERPRISEUSERDATAKEYS._serialized_start=2482
  _ENTERPRISEUSERDATAKEYS._serialized_end=2555
  _ENTERPRISEDATAREQUEST._serialized_start=2557
  _ENTERPRISEDATAREQUEST._serialized_end=2607
  _SPECIALPROVISIONING._serialized_start=2609
  _SPECIALPROVISIONING._serialized_end=2657
  _GENERALDATAENTITY._serialized_start=2660
  _GENERALDATAENTITY._serialized_end=2864
  _NODE._serialized_start=2867
  _NODE._serialized_end=3120
  _ROLE._serialized_start=3123
  _ROLE._serialized_end=3265
  _USER._serialized_start=3268
  _USER._serialized_end=3488
  _USERALIAS._serialized_start=3490
  _USERALIAS._serialized_end=3545
  _COMPLIANCEREPORTMETADATA._serialized_start=3548
  _COMPLIANCEREPORTMETADATA._serialized_end=3720
  _MANAGEDNODE._serialized_start=3722
  _MANAGEDNODE._serialized_end=3805
  _USERMANAGEDNODE._serialized_start=3807
  _USERMANAGEDNODE._serialized_end=3891
  _USERPRIVILEGE._serialized_start=3893
  _USERPRIVILEGE._serialized_end=4012
  _ROLEUSER._serialized_start=4014
  _ROLEUSER._serialized_end=4066
  _ROLEPRIVILEGE._serialized_start=4068
  _ROLEPRIVILEGE._serialized_end=4145
  _ROLEENFORCEMENT._serialized_start=4147
  _ROLEENFORCEMENT._serialized_end=4220
  _TEAM._serialized_start=4223
  _TEAM._serialized_end=4392
  _TEAMUSER._serialized_start=4394
  _TEAMUSER._serialized_end=4465
  _GETDISTRIBUTORINFORESPONSE._serialized_start=4467
  _GETDISTRIBUTORINFORESPONSE._serialized_end=4542
  _DISTRIBUTOR._serialized_start=4544
  _DISTRIBUTOR._serialized_end=4610
  _MSPINFO._serialized_start=4613
  _MSPINFO._serialized_end=4856
  _MANAGEDCOMPANY._serialized_start=4859
  _MANAGEDCOMPANY._serialized_end=5132
  _MSPPOOL._serialized_start=5134
  _MSPPOOL._serialized_end=5216
  _MSPCONTACT._serialized_start=5218
  _MSPCONTACT._serialized_end=5276
  _LICENSEADDON._serialized_start=5279
  _LICENSEADDON._serialized_end=5444
  _MCDEFAULT._serialized_start=5446
  _MCDEFAULT._serialized_end=5514
  _MSPPERMITS._serialized_start=5517
  _MSPPERMITS._serialized_end=5727
  _LICENSE._serialized_start=5730
  _LICENSE._serialized_end=6274
  _BRIDGE._serialized_start=6276
  _BRIDGE._serialized_end=6386
  _SCIM._serialized_start=6388
  _SCIM._serialized_end=6504
  _EMAILPROVISION._serialized_start=6506
  _EMAILPROVISION._serialized_end=6582
  _QUEUEDTEAM._serialized_start=6584
  _QUEUEDTEAM._serialized_end=6666
  _QUEUEDTEAMUSER._serialized_start=6668
  _QUEUEDTEAMUSER._serialized_end=6716
  _SSOSERVICE._serialized_start=6719
  _SSOSERVICE._serialized_end=6864
  _REPORTFILTERUSER._serialized_start=6866
  _REPORTFILTERUSER._serialized_end=6915
  _DEVICEREQUESTFORADMINAPPROVAL._serialized_start=6918
  _DEVICEREQUESTFORADMINAPPROVAL._serialized_end=7197
  _ENTERPRISEDATA._serialized_start=7199
  _ENTERPRISEDATA._serialized_end=7295
  _ENTERPRISEDATARESPONSE._serialized_start=7298
  _ENTERPRISEDATARESPONSE._serialized_end=7506
  _BACKUPREQUEST._serialized_start=7508
  _BACKUPREQUEST._serialized_end=7550
  _BACKUPRECORD._serialized_start=7553
  _BACKUPRECORD._serialized_end=7705
  _BACKUPKEY._serialized_start=7707
  _BACKUPKEY._serialized_end=7753
  _BACKUPUSER._serialized_start=7756
  _BACKUPUSER._serialized_end=8025
  _BACKUPRESPONSE._serialized_start=8028
  _BACKUPRESPONSE._serialized_end=8186
  _BACKUPFILE._serialized_start=8188
  _BACKUPFILE._serialized_end=8289
  _BACKUPSRESPONSE._serialized_start=8291
  _BACKUPSRESPONSE._serialized_end=8347
  _GETENTERPRISEDATAKEYSREQUEST._serialized_start=8349
  _GETENTERPRISEDATAKEYSREQUEST._serialized_end=8395
  _GETENTERPRISEDATAKEYSRESPONSE._serialized_start=8398
  _GETENTERPRISEDATAKEYSRESPONSE._serialized_end=8653
  _ROLEKEY._serialized_start=8655
  _ROLEKEY._serialized_end=8749
  _MSPKEY._serialized_start=8751
  _MSPKEY._serialized_end=8851
  _ENTERPRISEKEYS._serialized_start=8853
  _ENTERPRISEKEYS._serialized_end=8977
  _TREEKEY._serialized_start=8979
  _TREEKEY._serialized_end=9051
  _SHAREDRECORDRESPONSE._serialized_start=9053
  _SHAREDRECORDRESPONSE._serialized_end=9122
  _SHAREDRECORDEVENT._serialized_start=9124
  _SHAREDRECORDEVENT._serialized_end=9236
  _SETRESTRICTVISIBILITYREQUEST._serialized_start=9238
  _SETRESTRICTVISIBILITYREQUEST._serialized_end=9284
  _USERADDREQUEST._serialized_start=9287
  _USERADDREQUEST._serialized_end=9495
  _USERUPDATEREQUEST._serialized_start=9497
  _USERUPDATEREQUEST._serialized_end=9555
  _USERUPDATE._serialized_start=9558
  _USERUPDATE._serialized_end=9733
  _USERUPDATERESPONSE._serialized_start=9735
  _USERUPDATERESPONSE._serialized_end=9800
  _USERUPDATERESULT._serialized_start=9802
  _USERUPDATERESULT._serialized_end=9892
  _COMPLIANCERECORDOWNERSREQUEST._serialized_start=9894
  _COMPLIANCERECORDOWNERSREQUEST._serialized_end=9968
  _COMPLIANCERECORDOWNERSRESPONSE._serialized_start=9970
  _COMPLIANCERECORDOWNERSRESPONSE._serialized_end=10049
  _RECORDOWNER._serialized_start=10051
  _RECORDOWNER._serialized_end=10106
  _PRELIMINARYCOMPLIANCEDATAREQUEST._serialized_start=10109
  _PRELIMINARYCOMPLIANCEDATAREQUEST._serialized_end=10275
  _PRELIMINARYCOMPLIANCEDATARESPONSE._serialized_start=10278
  _PRELIMINARYCOMPLIANCEDATARESPONSE._serialized_end=10437
  _AUDITUSERRECORD._serialized_start=10439
  _AUDITUSERRECORD._serialized_end=10514
  _AUDITUSERDATA._serialized_start=10517
  _AUDITUSERDATA._serialized_end=10658
  _COMPLIANCEREPORTFILTERS._serialized_start=10660
  _COMPLIANCEREPORTFILTERS._serialized_end=10787
  _COMPLIANCEREPORTREQUEST._serialized_start=10789
  _COMPLIANCEREPORTREQUEST._serialized_end=10916
  _COMPLIANCEREPORTRUN._serialized_start=10919
  _COMPLIANCEREPORTRUN._serialized_end=11052
  _COMPLIANCEREPORTCRITERIAANDFILTER._serialized_start=11055
  _COMPLIANCEREPORTCRITERIAANDFILTER._serialized_end=11307
  _COMPLIANCEREPORTCRITERIA._serialized_start=11309
  _COMPLIANCEREPORTCRITERIA._serialized_end=11407
  _COMPLIANCEREPORTFILTER._serialized_start=11409
  _COMPLIANCEREPORTFILTER._serialized_end=11529
  _COMPLIANCEREPORTRESPONSE._serialized_start=11532
  _COMPLIANCEREPORTRESPONSE._serialized_end=12205
  _AUDITRECORD._serialized_start=12208
  _AUDITRECORD._serialized_end=12337
  _AUDITROLE._serialized_start=12340
  _AUDITROLE._serialized_end=12596
  _ROLENODEMANAGEMENT._serialized_start=12598
  _ROLENODEMANAGEMENT._serialized_end=12692
  _USERPROFILE._serialized_start=12694
  _USERPROFILE._serialized_end=12801
  _RECORDPERMISSION._serialized_start=12803
  _RECORDPERMISSION._serialized_end=12864
  _USERRECORD._serialized_start=12866
  _USERRECORD._serialized_end=12961
  _AUDITTEAM._serialized_start=12963
  _AUDITTEAM._serialized_end=13054
  _AUDITTEAMUSER._serialized_start=13056
  _AUDITTEAMUSER._serialized_end=13115
  _SHAREDFOLDERRECORD._serialized_start=13118
  _SHAREDFOLDERRECORD._serialized_end=13277
  _SHAREADMINRECORD._serialized_start=13279
  _SHAREADMINRECORD._serialized_end=13356
  _SHAREDFOLDERUSER._serialized_start=13358
  _SHAREDFOLDERUSER._serialized_end=13428
  _SHAREDFOLDERTEAM._serialized_start=13430
  _SHAREDFOLDERTEAM._serialized_end=13491
  _GETCOMPLIANCEREPORTREQUEST._serialized_start=13493
  _GETCOMPLIANCEREPORTREQUEST._serialized_end=13540
  _GETCOMPLIANCEREPORTRESPONSE._serialized_start=13542
  _GETCOMPLIANCEREPORTRESPONSE._serialized_end=13592
  _COMPLIANCEREPORTCRITERIAREQUEST._serialized_start=13594
  _COMPLIANCEREPORTCRITERIAREQUEST._serialized_end=13648
  _SAVECOMPLIANCEREPORTCRITERIARESPONSE._serialized_start=13650
  _SAVECOMPLIANCEREPORTCRITERIARESPONSE._serialized_end=13709
  _LINKEDRECORD._serialized_start=13711
  _LINKEDRECORD._serialized_end=13763
  _GETSHARINGADMINSREQUEST._serialized_start=13765
  _GETSHARINGADMINSREQUEST._serialized_end=13852
  _USERPROFILEEXT._serialized_start=13855
  _USERPROFILEEXT._serialized_end=14052
  _GETSHARINGADMINSRESPONSE._serialized_start=14054
  _GETSHARINGADMINSRESPONSE._serialized_end=14133
  _TEAMSENTERPRISEUSERSADDREQUEST._serialized_start=14135
  _TEAMSENTERPRISEUSERSADDREQUEST._serialized_end=14230
  _TEAMSENTERPRISEUSERSADDTEAMREQUEST._serialized_start=14232
  _TEAMSENTERPRISEUSERSADDTEAMREQUEST._serialized_end=14348
  _TEAMSENTERPRISEUSERSADDUSERREQUEST._serialized_start=14350
  _TEAMSENTERPRISEUSERSADDUSERREQUEST._serialized_end=14473
  _TEAMSENTERPRISEUSERSADDRESPONSE._serialized_start=14475
  _TEAMSENTERPRISEUSERSADDRESPONSE._serialized_end=14590
  _TEAMSENTERPRISEUSERSADDTEAMRESPONSE._serialized_start=14593
  _TEAMSENTERPRISEUSERSADDTEAMRESPONSE._serialized_end=14789
  _TEAMSENTERPRISEUSERSADDUSERRESPONSE._serialized_start=14792
  _TEAMSENTERPRISEUSERSADDUSERRESPONSE._serialized_end=14951
  _DOMAINALIAS._serialized_start=14953
  _DOMAINALIAS._serialized_end=15030
  _DOMAINALIASREQUEST._serialized_start=15032
  _DOMAINALIASREQUEST._serialized_end=15098
  _DOMAINALIASRESPONSE._serialized_start=15100
  _DOMAINALIASRESPONSE._serialized_end=15167
  _ENTERPRISEUSERSPROVISIONREQUEST._serialized_start=15169
  _ENTERPRISEUSERSPROVISIONREQUEST._serialized_end=15278
  _ENTERPRISEUSERSPROVISION._serialized_start=15281
  _ENTERPRISEUSERSPROVISION._serialized_end=15719
  _ENTERPRISEUSERSPROVISIONRESPONSE._serialized_start=15721
  _ENTERPRISEUSERSPROVISIONRESPONSE._serialized_end=15816
  _ENTERPRISEUSERSPROVISIONRESULT._serialized_start=15818
  _ENTERPRISEUSERSPROVISIONRESULT._serialized_end=15931
  _ENTERPRISEUSERSADDREQUEST._serialized_start=15933
  _ENTERPRISEUSERSADDREQUEST._serialized_end=16030
  _ENTERPRISEUSERSADD._serialized_start=16033
  _ENTERPRISEUSERSADD._serialized_end=16285
  _ENTERPRISEUSERSADDRESPONSE._serialized_start=16288
  _ENTERPRISEUSERSADDRESPONSE._serialized_end=16443
  _ENTERPRISEUSERSADDRESULT._serialized_start=16446
  _ENTERPRISEUSERSADDRESULT._serialized_end=16596
  _UPDATEMSPPERMITSREQUEST._serialized_start=16599
  _UPDATEMSPPERMITSREQUEST._serialized_end=16784
# @@protoc_insertion_point(module_scope)
